@@ -17,23 +17,22 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef DT_BAUHAUS_H
-#define DT_BAUHAUS_H
+#pragma once
 
+#include "common/debug.h"
+#include "control/control.h"
 #include "develop/develop.h"
 #include "develop/imageop.h"
-#include "control/control.h"
-#include "common/debug.h"
-#include "gui/gtk.h"
 #include "gui/draw.h"
+#include "gui/gtk.h"
 
-#include <stdlib.h>
-#include <math.h>
 #include <assert.h>
-#include <string.h>
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <inttypes.h>
-#include <gdk/gdkkeysyms.h>
+#include <math.h>
+#include <stdlib.h>
+#include <string.h>
 
 #define DT_BAUHAUS_WIDGET_TYPE (dt_bh_get_type())
 #define DT_BAUHAUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), DT_BAUHAUS_WIDGET_TYPE, DtBauhausWidget))
@@ -55,6 +54,12 @@ typedef enum dt_bauhaus_type_t
   // TODO: all the fancy color sliders..
 } dt_bauhaus_type_t;
 
+typedef enum dt_bauhaus_callback_t
+{
+  DT_BAUHAUS_SET = 1,
+  DT_BAUHAUS_GET = 2
+} dt_bauhaus_callback_t;
+
 // data portion for a slider
 typedef struct dt_bauhaus_slider_data_t
 {
@@ -79,17 +84,25 @@ typedef struct dt_bauhaus_slider_data_t
   int is_dragging;      // indicates is mouse is dragging slider
   int is_changed;       // indicates new data
   guint timeout_handle; // used to store id of timeout routine
+  float (*callback)(GtkWidget*, float, dt_bauhaus_callback_t); // callback function
 } dt_bauhaus_slider_data_t;
 
+typedef enum dt_bauhaus_combobox_alignment_t
+{
+  DT_BAUHAUS_COMBOBOX_ALIGN_LEFT = 0,
+  DT_BAUHAUS_COMBOBOX_ALIGN_RIGHT = 1
+} dt_bauhaus_combobox_alignment_t;
+
 // data portion for a combobox
 typedef struct dt_bauhaus_combobox_data_t
 {
-  int num_labels; // number of elements
-  int active;     // currently active element
-  int defpos;     // default position
-  int editable;   // 1 if arbitrary text may be typed
-  char text[180]; // roughly as much as a slider
-  GList *labels;  // list of elements
+  int num_labels;    // number of elements
+  int active;        // currently active element
+  int defpos;        // default position
+  int editable;      // 1 if arbitrary text may be typed
+  char text[180];    // roughly as much as a slider
+  GList *labels;     // list of elements
+  GList *alignments; // alignments of the labels. we keep this extra to make it easy to pass the labels around
 } dt_bauhaus_combobox_data_t;
 
 typedef union dt_bauhaus_data_t
@@ -246,18 +259,24 @@ float dt_bauhaus_slider_get_hard_min(GtkWidget* w);
 void dt_bauhaus_slider_set_hard_max(GtkWidget* w, float val);
 float dt_bauhaus_slider_get_hard_max(GtkWidget* w);
 
-float dt_bauhaus_slider_get_step(GtkWidget *widget);
+void dt_bauhaus_slider_set_digits(GtkWidget *w, int val);
+int dt_bauhaus_slider_get_digits(GtkWidget *w);
+void dt_bauhaus_slider_set_step(GtkWidget *w, float val);
+float dt_bauhaus_slider_get_step(GtkWidget *w);
+
 void dt_bauhaus_slider_reset(GtkWidget *widget);
 void dt_bauhaus_slider_set_format(GtkWidget *w, const char *format);
 void dt_bauhaus_slider_set_stop(GtkWidget *widget, float stop, float r, float g, float b);
 void dt_bauhaus_slider_set_default(GtkWidget *widget, float def);
 void dt_bauhaus_slider_enable_soft_boundaries(GtkWidget *widget, float hard_min, float hard_max);
+void dt_bauhaus_slider_set_callback(GtkWidget *widget, float (*callback)(GtkWidget *self, float value, dt_bauhaus_callback_t dir));
 
 // combobox:
 void dt_bauhaus_combobox_from_widget(dt_bauhaus_widget_t* widget,dt_iop_module_t *self);
 GtkWidget *dt_bauhaus_combobox_new(dt_iop_module_t *self);
 
 void dt_bauhaus_combobox_add(GtkWidget *widget, const char *text);
+void dt_bauhaus_combobox_add_aligned(GtkWidget *widget, const char *text, dt_bauhaus_combobox_alignment_t align);
 void dt_bauhaus_combobox_set(GtkWidget *w, int pos);
 void dt_bauhaus_combobox_remove_at(GtkWidget *widget, int pos);
 void dt_bauhaus_combobox_insert(GtkWidget *widget, const char *text,int pos);
@@ -278,7 +297,6 @@ void dt_bauhaus_vimkey_exec(const char *input);
 // give autocomplete suggestions
 GList *dt_bauhaus_vimkey_complete(const char *input);
 
-#endif
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
