@@ -831,8 +831,9 @@ static gchar *get_query_string(const dt_collection_properties_t property, const
       break;
 
     case DT_COLLECTION_PROP_FOLDERS: // folders
-      query = dt_util_dstrcat(query, "(film_id IN (SELECT id FROM main.film_rolls WHERE folder LIKE '%s%%'))",
-                              escaped_text);
+      query = dt_util_dstrcat(
+          query, "(film_id IN (SELECT id FROM main.film_rolls WHERE folder LIKE '%1$s' OR folder LIKE '%1$s/%%'))",
+          escaped_text);
       break;
 
     case DT_COLLECTION_PROP_COLORLABEL: // colorlabel
