@@ -21,6 +21,11 @@
 #include "common/darktable.h"
 #include <lcms2.h>
 
+// this was removed from lcms2 in 2.4
+#ifndef TYPE_XYZA_FLT
+  #define TYPE_XYZA_FLT         (FLOAT_SH(1)|COLORSPACE_SH(PT_XYZ)|EXTRA_SH(1)|CHANNELS_SH(3)|BYTES_SH(4))
+#endif
+
 // constants fit to the ones from lcms.h:
 typedef enum dt_iop_color_intent_t
 {
