@@ -157,7 +157,6 @@ typedef enum dt_debug_thread_t
   DT_DEBUG_CACHE = 1 << 0,
   DT_DEBUG_CONTROL = 1 << 1,
   DT_DEBUG_DEV = 1 << 2,
-  DT_DEBUG_FSWATCH = 1 << 3,
   DT_DEBUG_PERF = 1 << 4,
   DT_DEBUG_CAMCTL = 1 << 5,
   DT_DEBUG_PWSTORAGE = 1 << 6,
@@ -200,7 +199,6 @@ typedef struct darktable_t
   struct dt_image_cache_t *image_cache;
   struct dt_bauhaus_t *bauhaus;
   const struct dt_database_t *db;
-  const struct dt_fswatch_t *fswatch;
   const struct dt_pwstorage_t *pwstorage;
   const struct dt_camctl_t *camctl;
   const struct dt_collection_t *collection;
