@@ -15,8 +15,9 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef DT_COMMON_FOCUS_H
-#define DT_COMMON_FOCUS_H
+#pragma once
+
+#include "common/image_cache.h"
 
 typedef struct dt_focus_cluster_t
 {
@@ -124,8 +125,8 @@ static void _dt_focus_update(dt_focus_cluster_t *f, int frows, int fcols, int i,
 
 
 // read 8-bit buffer and create focus clusters from it
-void dt_focus_create_clusters(dt_focus_cluster_t *focus, int frows, int fcols, uint8_t *buffer,
-                              int buffer_width, int buffer_height)
+static void dt_focus_create_clusters(dt_focus_cluster_t *focus, int frows, int fcols, uint8_t *buffer,
+                                     int buffer_width, int buffer_height)
 {
   // mark in-focus pixels:
   const int wd = buffer_width;
@@ -214,8 +215,8 @@ void dt_focus_create_clusters(dt_focus_cluster_t *focus, int frows, int fcols, u
   }
 }
 
-void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid, int buffer_width,
-                            int buffer_height, dt_focus_cluster_t *focus, int frows, int fcols)
+static void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid, int buffer_width,
+                                   int buffer_height, dt_focus_cluster_t *focus, int frows, int fcols)
 {
   const int fs = frows * fcols;
   cairo_save(cr);
@@ -229,7 +230,8 @@ void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid, int b
   int wd = buffer_width + image.crop_x, ht = buffer_height + image.crop_y;
 
   // array with cluster positions
-  float pos[fs * 6], *offx = pos + fs * 2, *offy = pos + fs * 4;
+  float *pos = malloc(fs * 6 * sizeof(float));
+  float *offx = pos + fs * 2, *offy = pos + fs * 4;
   for(int k = 0; k < fs; k++)
   {
     const float stddevx = sqrtf(focus[k].x2 - focus[k].x * focus[k].x);
@@ -256,7 +258,7 @@ void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid, int b
     if(res)
     {
       // set mem pointer to 0, won't be used.
-      dt_dev_pixelpipe_set_input(&pipe, &dev, NULL, wd, ht, 1.0f, 0);
+      dt_dev_pixelpipe_set_input(&pipe, &dev, NULL, wd, ht, 1.0f);
       dt_dev_pixelpipe_create_nodes(&pipe, &dev);
       dt_dev_pixelpipe_synch_all(&pipe, &dev);
       dt_dev_pixelpipe_get_dimensions(&pipe, &dev, pipe.iwidth, pipe.iheight, &pipe.processed_width,
@@ -339,8 +341,12 @@ void dt_focus_draw_clusters(cairo_t *cr, int width, int height, int imgid, int b
     }
   }
   cairo_restore(cr);
+  free(pos);
 }
 #undef CHANNEL
 #undef gbuf
 #undef FOCUS_THRS
-#endif
+
+// modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
+// vim: shiftwidth=2 expandtab tabstop=2 cindent
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
