@@ -17,14 +17,20 @@
 */
 
 
-#include <math.h>
 #include <assert.h>
+#include <math.h>
+#if defined(__SSE__)
 #include <xmmintrin.h>
-#include "common/opencl.h"
+#endif
 #include "common/gaussian.h"
+#include "common/opencl.h"
 
 #define CLAMPF(a, mn, mx) ((a) < (mn) ? (mn) : ((a) > (mx) ? (mx) : (a)))
+
+#if defined(__SSE__)
 #define MMCLAMPPS(a, mn, mx) (_mm_min_ps((mx), _mm_max_ps((a), (mn))))
+#endif
+
 #define BLOCKSIZE 32
 
 static void compute_gauss_params(const float sigma, dt_gaussian_order_t order, float *a0, float *a1,
@@ -149,12 +155,12 @@ error:
 }
 
 
-void dt_gaussian_blur(dt_gaussian_t *g, float *in, float *out)
+void dt_gaussian_blur(dt_gaussian_t *g, const float *const in, float *const out)
 {
 
   const int width = g->width;
   const int height = g->height;
-  const int ch = g->channels;
+  const int ch = MIN(4, g->channels); // just to appease zealous compiler warnings about stack usage
 
   float a0, a1, a2, a3, b1, b2, coefp, coefn;
 
@@ -167,20 +173,20 @@ void dt_gaussian_blur(dt_gaussian_t *g, float *in, float *out)
 
 // vertical blur column by column
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(in, out, temp, Labmin, Labmax, a0, a1, a2, a3, b1, b2, coefp,  \
+#pragma omp parallel for default(none) shared(temp, Labmin, Labmax, a0, a1, a2, a3, b1, b2, coefp,           \
                                               coefn) schedule(static)
 #endif
   for(int i = 0; i < width; i++)
   {
-    float xp[ch];
-    float yb[ch];
-    float yp[ch];
-    float xc[ch];
-    float yc[ch];
-    float xn[ch];
-    float xa[ch];
-    float yn[ch];
-    float ya[ch];
+    float xp[4] = {0.0f};
+    float yb[4] = {0.0f};
+    float yp[4] = {0.0f};
+    float xc[4] = {0.0f};
+    float yc[4] = {0.0f};
+    float xn[4] = {0.0f};
+    float xa[4] = {0.0f};
+    float yn[4] = {0.0f};
+    float ya[4] = {0.0f};
 
     // forward filter
     for(int k = 0; k < ch; k++)
@@ -239,20 +245,20 @@ void dt_gaussian_blur(dt_gaussian_t *g, float *in, float *out)
 
 // horizontal blur line by line
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(out, temp, Labmin, Labmax, a0, a1, a2, a3, b1, b2, coefp,      \
+#pragma omp parallel for default(none) shared(temp, Labmin, Labmax, a0, a1, a2, a3, b1, b2, coefp,           \
                                               coefn) schedule(static)
 #endif
   for(int j = 0; j < height; j++)
   {
-    float xp[ch];
-    float yb[ch];
-    float yp[ch];
-    float xc[ch];
-    float yc[ch];
-    float xn[ch];
-    float xa[ch];
-    float yn[ch];
-    float ya[ch];
+    float xp[4] = {0.0f};
+    float yb[4] = {0.0f};
+    float yp[4] = {0.0f};
+    float xc[4] = {0.0f};
+    float yc[4] = {0.0f};
+    float xn[4] = {0.0f};
+    float xa[4] = {0.0f};
+    float yn[4] = {0.0f};
+    float ya[4] = {0.0f};
 
     // forward filter
     for(int k = 0; k < ch; k++)
@@ -312,7 +318,8 @@ void dt_gaussian_blur(dt_gaussian_t *g, float *in, float *out)
 
 
 
-void dt_gaussian_blur_4c(dt_gaussian_t *g, float *in, float *out)
+#if defined(__SSE__)
+static void dt_gaussian_blur_4c_sse(dt_gaussian_t *g, const float *const in, float *const out)
 {
 
   const int width = g->width;
@@ -333,8 +340,7 @@ void dt_gaussian_blur_4c(dt_gaussian_t *g, float *in, float *out)
 
 // vertical blur column by column
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(in, out, temp, a0, a1, a2, a3, b1, b2, coefp,                  \
-                                              coefn) schedule(static)
+#pragma omp parallel for default(none) shared(temp, a0, a1, a2, a3, b1, b2, coefp, coefn) schedule(static)
 #endif
   for(int i = 0; i < width; i++)
   {
@@ -402,8 +408,7 @@ void dt_gaussian_blur_4c(dt_gaussian_t *g, float *in, float *out)
 
 // horizontal blur line by line
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(out, temp, a0, a1, a2, a3, b1, b2, coefp,                      \
-                                              coefn) schedule(static)
+#pragma omp parallel for default(none) shared(temp, a0, a1, a2, a3, b1, b2, coefp, coefn) schedule(static)
 #endif
   for(size_t j = 0; j < height; j++)
   {
@@ -469,7 +474,18 @@ void dt_gaussian_blur_4c(dt_gaussian_t *g, float *in, float *out)
     }
   }
 }
+#endif
 
+void dt_gaussian_blur_4c(dt_gaussian_t *g, const float *const in, float *const out)
+{
+  if(darktable.codepath.OPENMP_SIMD) return dt_gaussian_blur(g, in, out);
+#if defined(__SSE__)
+  else if(darktable.codepath.SSE2)
+    return dt_gaussian_blur_4c_sse(g, in, out);
+#endif
+  else
+    dt_unreachable_codepath();
+}
 
 void dt_gaussian_free(dt_gaussian_t *g)
 {
@@ -503,8 +519,8 @@ void dt_gaussian_free_cl(dt_gaussian_cl_t *g)
   free(g->min);
   free(g->max);
   // free device mem
-  if(g->dev_temp1) dt_opencl_release_mem_object(g->dev_temp1);
-  if(g->dev_temp2) dt_opencl_release_mem_object(g->dev_temp2);
+  dt_opencl_release_mem_object(g->dev_temp1);
+  dt_opencl_release_mem_object(g->dev_temp2);
   free(g);
 }
 
@@ -598,8 +614,8 @@ dt_gaussian_cl_t *dt_gaussian_init_cl(const int devid,
 error:
   free(g->min);
   free(g->max);
-  if(g->dev_temp1) dt_opencl_release_mem_object(g->dev_temp1);
-  if(g->dev_temp2) dt_opencl_release_mem_object(g->dev_temp2);
+  dt_opencl_release_mem_object(g->dev_temp1);
+  dt_opencl_release_mem_object(g->dev_temp2);
   g->dev_temp1 = g->dev_temp2 = NULL;
   free(g);
   return NULL;
@@ -753,3 +769,6 @@ void dt_gaussian_free_cl_global(dt_gaussian_cl_global_t *g)
 }
 
 #endif
+// modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
+// vim: shiftwidth=2 expandtab tabstop=2 cindent
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
