@@ -138,8 +138,19 @@ static inline int _read_planar_f(tiff_t *t)
   return 1;
 }
 
+static void _warning_handler(const char* module, const char* fmt, va_list ap)
+{
+  fprintf(stderr, "[tiff_open] warning: %s: ", module);
+  vfprintf(stderr, fmt, ap);
+  fprintf(stderr, "\n");
+}
+
 dt_imageio_retval_t dt_imageio_open_tiff(dt_image_t *img, const char *filename, dt_mipmap_buffer_t *mbuf)
 {
+  // doing this once would be enough, but our imageio reading code is
+  // compiled into dt's core and doesn't have an init routine.
+  TIFFSetWarningHandler(_warning_handler);
+
   const char *ext = filename + strlen(filename);
   while(*ext != '.' && ext > filename) ext--;
   if(strncmp(ext, ".tif", 4) && strncmp(ext, ".TIF", 4) && strncmp(ext, ".tiff", 5)
