@@ -18,11 +18,11 @@
 
 #include <stdio.h>
 
-#include "control/conf.h"
-#include "control/control.h"
 #include "common/film.h"
 #include "common/import_session.h"
 #include "common/variables.h"
+#include "control/conf.h"
+#include "control/control.h"
 
 /* TODO: Investigate if we can make one import session instance thread safe
          eg. having several background jobs working with same instance.
@@ -204,6 +204,13 @@ void dt_import_session_set_time(struct dt_import_session_t *self, time_t time)
 }
 
 
+void
+dt_import_session_set_exif_time(struct dt_import_session_t *self, time_t exif_time)
+{
+  dt_variables_set_exif_time(self->vp, exif_time);
+}
+
+
 void dt_import_session_set_filename(struct dt_import_session_t *self, const char *filename)
 {
   self->vp->filename = filename;
@@ -248,6 +255,7 @@ const char *dt_import_session_filename(struct dt_import_session_t *self, gboolea
   gchar *result_fname = dt_variables_get_result(self->vp);
   previous_fname = fname = g_build_path(G_DIR_SEPARATOR_S, path, result_fname, (char *)NULL);
   g_free(result_fname);
+  result_fname = NULL;
   if(g_file_test(fname, G_FILE_TEST_EXISTS) == TRUE)
   {
     fprintf(stderr, "[import_session] File %s exists.\n", fname);
@@ -256,9 +264,10 @@ const char *dt_import_session_filename(struct dt_import_session_t *self, gboolea
       /* file exists, yield a new filename */
       dt_variables_expand(self->vp, pattern, TRUE);
 
-      gchar *result_fname = dt_variables_get_result(self->vp);
+      result_fname = dt_variables_get_result(self->vp);
       fname = g_build_path(G_DIR_SEPARATOR_S, path, result_fname, (char *)NULL);
       g_free(result_fname);
+      result_fname = NULL;
 
       fprintf(stderr, "[import_session] Testing %s.\n", fname);
       /* check if same filename was yielded as before */
@@ -322,3 +331,6 @@ const char *dt_import_session_path(struct dt_import_session_t *self, gboolean cu
 
   return self->current_path;
 }
+// modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
+// vim: shiftwidth=2 expandtab tabstop=2 cindent
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
