@@ -16,15 +16,14 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __INTROSPECTION_H__
-#define __INTROSPECTION_H__
+#pragma once
 
-#include <stdlib.h>
 #include <glib.h>
+#include <stdlib.h>
 
 // some typedefs for structs that hold the data in a machine readable form
 
-#define DT_INTROSPECTION_VERSION 4
+#define DT_INTROSPECTION_VERSION 5
 
 // clang-format off
 
@@ -37,6 +36,7 @@ typedef enum dt_introspection_type_t
   DT_INTROSPECTION_TYPE_OPAQUE,
   DT_INTROSPECTION_TYPE_FLOAT,
   DT_INTROSPECTION_TYPE_DOUBLE,
+  DT_INTROSPECTION_TYPE_FLOATCOMPLEX,
   DT_INTROSPECTION_TYPE_CHAR,
   DT_INTROSPECTION_TYPE_UCHAR,
   DT_INTROSPECTION_TYPE_SHORT,
@@ -48,7 +48,8 @@ typedef enum dt_introspection_type_t
   DT_INTROSPECTION_TYPE_BOOL,
   DT_INTROSPECTION_TYPE_ARRAY,
   DT_INTROSPECTION_TYPE_ENUM,
-  DT_INTROSPECTION_TYPE_STRUCT
+  DT_INTROSPECTION_TYPE_STRUCT,
+  DT_INTROSPECTION_TYPE_UNION
 } dt_introspection_type_t;
 
 typedef struct dt_introspection_type_header_t
@@ -84,6 +85,14 @@ typedef struct dt_introspection_type_double_t
   double                              Default;      // default value for this double field. taken from comments. defaults to 0
 } dt_introspection_type_double_t;
 
+typedef struct dt_introspection_type_float_complex_t
+{
+  dt_introspection_type_header_t      header;
+//   float complex                       Min;       // unfortunately we can't have these for "float complex",
+//   float complex                       Max;       // because we'd have to #include<complex.h> which doesn't seem to work with C++,
+//   float complex                       Default;   // at least in a quick test.
+} dt_introspection_type_float_complex_t;
+
 typedef struct dt_introspection_type_char_t
 {
   dt_introspection_type_header_t      header;
@@ -182,25 +191,34 @@ typedef struct dt_introspection_type_struct_t
   union dt_introspection_field_t    **fields;       // the fields of the struct. NULL terminated
 } dt_introspection_type_struct_t;
 
+typedef struct dt_introspection_type_union_t
+{
+  dt_introspection_type_header_t      header;
+  size_t                              entries;      // # entries in fields (without the closing NULL)
+  union dt_introspection_field_t    **fields;       // the fields of the union. NULL terminated
+} dt_introspection_type_union_t;
+
 // sorry for the camel case/Capitals, but we have to avoid reserved keywords
 typedef union dt_introspection_field_t
 {
-  dt_introspection_type_header_t      header;       // the common header
-  dt_introspection_type_opaque_t      Opaque;       // some binary blob
-  dt_introspection_type_float_t       Float;        // a float
-  dt_introspection_type_double_t      Double;       // a double
-  dt_introspection_type_char_t        Char;         // a char
-  dt_introspection_type_uchar_t       UChar;        // an unsigned char
-  dt_introspection_type_short_t       Short;        // a short
-  dt_introspection_type_ushort_t      UShort;       // an unsigned short
-  dt_introspection_type_int_t         Int;          // an int
-  dt_introspection_type_uint_t        UInt;         // an unsigned int
-  dt_introspection_type_long_t        Long;         // a long
-  dt_introspection_type_ulong_t       ULong;        // an unsigned long
-  dt_introspection_type_bool_t        Bool;         // a gboolean
-  dt_introspection_type_array_t       Array;        // an array
-  dt_introspection_type_enum_t        Enum;         // an enum
-  dt_introspection_type_struct_t      Struct;       // a struct
+  dt_introspection_type_header_t        header;        // the common header
+  dt_introspection_type_opaque_t        Opaque;        // some binary blob
+  dt_introspection_type_float_t         Float;         // a float
+  dt_introspection_type_double_t        Double;        // a double
+  dt_introspection_type_float_complex_t FloatComplex;  // a float complex
+  dt_introspection_type_char_t          Char;          // a char
+  dt_introspection_type_uchar_t         UChar;         // an unsigned char
+  dt_introspection_type_short_t         Short;         // a short
+  dt_introspection_type_ushort_t        UShort;        // an unsigned short
+  dt_introspection_type_int_t           Int;           // an int
+  dt_introspection_type_uint_t          UInt;          // an unsigned int
+  dt_introspection_type_long_t          Long;          // a long
+  dt_introspection_type_ulong_t         ULong;         // an unsigned long
+  dt_introspection_type_bool_t          Bool;          // a gboolean
+  dt_introspection_type_array_t         Array;         // an array
+  dt_introspection_type_enum_t          Enum;          // an enum
+  dt_introspection_type_struct_t        Struct;        // a struct
+  dt_introspection_type_union_t         Union;         // an union
 } dt_introspection_field_t;
 
 typedef struct dt_introspection_t
@@ -279,8 +297,6 @@ static inline const char *dt_introspection_get_enum_name(dt_introspection_field_
   return NULL;
 }
 
-#endif // __INTROSPECTION_H__
-
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
