@@ -15,8 +15,8 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef DT_OPENCL_H
-#define DT_OPENCL_H
+
+#pragma once
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -34,8 +34,8 @@
 #ifdef HAVE_OPENCL
 
 #include "common/darktable.h"
-#include "common/dtpthread.h"
 #include "common/dlopencl.h"
+#include "common/dtpthread.h"
 #include "control/conf.h"
 
 // #pragma GCC diagnostic push
@@ -111,6 +111,7 @@ typedef struct dt_opencl_t
   int number_event_handles;
   int print_statistics;
   int synch_cache;
+  int enable_markesteijn;
   int micro_nap;
   int enabled;
   int stopped;
@@ -134,6 +135,12 @@ typedef struct dt_opencl_t
   struct dt_interpolation_cl_global_t *interpolation;
 } dt_opencl_t;
 
+/** internally calls dt_clGetDeviceInfo, and takes care of memory allocation
+ * afterwards, *param_value will point to memory block of size at least *param_value
+ * which needs to be free()'d manually */
+int dt_opencl_get_device_info(dt_opencl_t *cl, cl_device_id device, cl_device_info param_name, void **param_value,
+                              size_t *param_value_size);
+
 /** inits the opencl subsystem. */
 void dt_opencl_init(dt_opencl_t *cl, const gboolean exclude_opencl, const gboolean print_statistics);
 
@@ -273,7 +280,7 @@ void *dt_opencl_alloc_device_buffer(const int devid, const size_t size);
 
 void *dt_opencl_alloc_device_buffer_with_flags(const int devid, const size_t size, const int flags);
 
-void dt_opencl_release_mem_object(void *mem);
+void dt_opencl_release_mem_object(cl_mem mem);
 
 void *dt_opencl_map_buffer(const int devid, cl_mem buffer, const int blocking, const int flags, size_t offset,
                            size_t size);
@@ -308,8 +315,8 @@ cl_int dt_opencl_events_flush(const int devid, const int reset);
 void dt_opencl_events_profiling(const int devid, const int aggregated);
 
 #else
-#include <stdlib.h>
 #include "control/conf.h"
+#include <stdlib.h>
 typedef struct dt_opencl_t
 {
   int inited;
@@ -432,8 +439,6 @@ static inline void dt_opencl_events_profiling(const int devid, const int aggrega
 }
 #endif
 
-
-#endif
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
