@@ -16,10 +16,11 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef __PRINTPROF_H__
-#define __PRINTPROF_H__
+#pragma once
 
+#include <glib.h>
 #include <inttypes.h>
+#include <lcms2.h>
 #include <stddef.h>
 
 int dt_apply_printer_profile(int imgid, void **in, uint32_t width, uint32_t height, int bpp,
@@ -27,8 +28,6 @@ int dt_apply_printer_profile(int imgid, void **in, uint32_t width, uint32_t heig
 // this routines takes as input an image of 8 or 16 bpp but always return a 8 bpp result. It is indeed better to
 // apply the profile to a 16bit input but we do not need this for printing.
 
-#endif // __PRINTPROF_H__
-
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
