@@ -15,8 +15,8 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef DT_USER_CONFIG_H
-#define DT_USER_CONFIG_H
+
+#pragma once
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -26,12 +26,12 @@
 #include "common/darktable.h"
 #include "common/file_location.h"
 
+#include <glib.h>
+#include <glib/gprintf.h>
 #include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <strings.h>
-#include <glib.h>
-#include <glib/gprintf.h>
 
 typedef struct dt_conf_t
 {
@@ -342,7 +342,6 @@ static inline void dt_conf_string_entry_free(gpointer data)
   g_free(nv);
 }
 
-#endif
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
