@@ -104,14 +104,6 @@ void dt_control_progress_destroy(dt_control_t *control, dt_progress_t *progress)
   }
 #endif
 
-#ifdef MAC_INTEGRATION
-#ifdef GTK_TYPE_OSX_APPLICATION
-  gtk_osxapplication_attention_request(g_object_new(GTK_TYPE_OSX_APPLICATION, NULL), INFO_REQUEST);
-#else
-  gtkosx_application_attention_request(g_object_new(GTKOSX_TYPE_APPLICATION, NULL), INFO_REQUEST);
-#endif
-#endif
-
   // free the object
   dt_pthread_mutex_destroy(&progress->mutex);
   g_free(progress->message);
@@ -197,6 +189,21 @@ const gchar *dt_control_progress_get_message(dt_progress_t *progress)
   return res;
 }
 
+void dt_control_progress_set_message(dt_control_t *control, dt_progress_t *progress, const char *message)
+{
+  dt_pthread_mutex_lock(&progress->mutex);
+  g_free(progress->message);
+  progress->message = g_strdup(message);
+  dt_pthread_mutex_unlock(&progress->mutex);
+
+  // tell the gui
+  dt_pthread_mutex_lock(&control->progress_system.mutex);
+  if(control->progress_system.proxy.module != NULL)
+    control->progress_system.proxy.message_updated(control->progress_system.proxy.module, progress->gui_data,
+                                                   message);
+  dt_pthread_mutex_unlock(&control->progress_system.mutex);
+}
+
 void dt_control_progress_set_gui_data(dt_progress_t *progress, void *data)
 {
   dt_pthread_mutex_lock(&progress->mutex);
@@ -230,4 +237,4 @@ gboolean dt_control_progress_cancellable(dt_progress_t *progress)
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
