@@ -17,13 +17,12 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef DT_DEVELOP_BLEND_H
-#define DT_DEVELOP_BLEND_H
+#pragma once
 
+#include "common/opencl.h"
+#include "develop/pixelpipe.h"
 #include "dtgtk/button.h"
 #include "dtgtk/gradientslider.h"
-#include "develop/pixelpipe.h"
-#include "common/opencl.h"
 
 #define DEVELOP_BLEND_VERSION (7)
 
@@ -282,7 +281,6 @@ typedef struct dt_blendop_t
   int kernel_blendop_Lab;
   int kernel_blendop_RAW;
   int kernel_blendop_rgb;
-  int kernel_blendop_copy_alpha;
   int kernel_blendop_set_mask;
 } dt_blendop_t;
 
@@ -367,8 +365,9 @@ typedef struct dt_iop_gui_blend_data_t
 void dt_develop_blend_init(dt_blendop_t *gd);
 
 /** apply blend */
-void dt_develop_blend_process(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, void *i,
-                              void *o, const struct dt_iop_roi_t *roi_in, const struct dt_iop_roi_t *roi_out);
+void dt_develop_blend_process(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece,
+                              const void *const i, void *const o, const struct dt_iop_roi_t *const roi_in,
+                              const struct dt_iop_roi_t *const roi_out);
 
 /** get blend version */
 int dt_develop_blend_version(void);
@@ -401,8 +400,6 @@ int dt_develop_blend_process_cl(struct dt_iop_module_t *self, struct dt_dev_pixe
                                 const struct dt_iop_roi_t *roi_out);
 #endif
 
-#endif
-
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
