@@ -15,8 +15,9 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef DT_DEV_PIXELPIPE_H
-#define DT_DEV_PIXELPIPE_H
+
+#pragma once
+
 #include <stdint.h>
 
 #ifdef HAVE_CONFIG_H
@@ -64,16 +65,13 @@ typedef struct dt_dev_histogram_stats_t
   uint32_t ch;
 } dt_dev_histogram_stats_t;
 
+#ifndef DT_IOP_PARAMS_T
+#define DT_IOP_PARAMS_T
 typedef void dt_iop_params_t;
+#endif
 
-#ifdef HAVE_GEGL
-#include "develop/pixelpipe_gegl.h"
-#else
 #include "develop/pixelpipe_hb.h"
-#endif
-
-#endif
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
