@@ -43,6 +43,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Canon EOS 50D", { 4920,616,-593,-6493,13964,2784,-1774,3178,7005 } },
     { "Canon EOS 60D", { 6719,-994,-925,-4408,12426,2211,-887,2129,6051 } },
     { "Canon EOS 70D", { 7034,-804,-1014,-4420,12564,2058,-851,1994,5758 } },
+    { "Canon EOS 77D", { 7377,-742,-998,-4235,11981,2549,-673,1918,5538 } },
     { "Canon EOS 80D", { 7457,-671,-937,-4849,12495,2643,-1213,2354,5492 } },
     { "Canon EOS 100D", { 6602,-841,-939,-4472,12458,2247,-975,2039,6148 } },
     { "Canon EOS 300D", { 8197,-2000,-1118,-6714,14335,2592,-2536,3178,8266 } },
@@ -288,6 +289,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Nikon D5200", { 8322,-3112,-1047,-6367,14342,2179,-988,1638,6394 } },
     { "Nikon D5300", { 6988,-1384,-714,-5631,13410,2447,-1485,2204,7318 } },
     { "Nikon D5500", { 8821,-2938,-785,-4178,12142,2287,-824,1651,6860 } },
+    { "Nikon D5600", { 8821,-2938,-785,-4178,12142,2287,-824,1651,6860 } },
     { "Nikon D500", { 8813,-3210,-1036,-4703,12868,2021,-1054,1940,6129 } },
     { "Nikon D50", { 7732,-2422,-789,-8238,15884,2498,-859,783,7330 } },
     { "Nikon D600", { 8178,-2245,-609,-4857,12394,2776,-1207,2086,7298 } },
@@ -494,6 +496,8 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Panasonic DMC-TZ61", { 8607,-2822,-808,-3755,11930,2049,-820,2060,5224 } },
     { "Panasonic DMC-TZ71", { 8802,-3135,-789,-3151,11468,1904,-550,1745,4810 } },
     { "Panasonic DMC-TZ100", { 7790,-2736,-755,-3452,11870,1769,-628,1647,4898 } },
+    { "Panasonic DC-FZ82", { 8550,-2908,-842,-3195,11529,1881,-338,1603,4631 } },
+    { "Panasonic DC-GH5", { 7641,-2336,-605,-3218,11299,2187,-485,1338,5121 } },
     { "Phase One H 20", { 1313,1855,-109,-6715,15908,808,-327,1840,6020 } }, /* DJC */
     { "Phase One H 25", { 2905,732,-237,-8134,16626,1476,-3038,4253,7517 } },
     { "Phase One P 2", { 2905,732,-237,-8134,16626,1476,-3038,4253,7517 } },
