@@ -28,13 +28,24 @@ namespace RawSpeed {
 
 using namespace pugi;
 
+struct CameraId {
+  std::string make;
+  std::string model;
+  std::string mode;
+
+  bool operator<(const CameraId& rhs) const {
+    return std::tie(make, model, mode) <
+           std::tie(rhs.make, rhs.model, rhs.mode);
+  }
+};
+
 class CameraMetaData
 {
 public:
   CameraMetaData();
   CameraMetaData(const char *docname);
   virtual ~CameraMetaData(void);
-  map<string,Camera*> cameras;
+  std::map<CameraId, Camera*> cameras;
   map<uint32,Camera*> chdkCameras;
 
   // searches for camera with given make + model + mode
