@@ -62,6 +62,7 @@ RawImage Cr2Decoder::decodeRawInternal() {
       b = new ByteStreamSwap(mFile, off+41);
     uint32 height = b->getShort();
     uint32 width = b->getShort();
+    delete b;
 
     // Every two lines can be encoded as a single line, probably to try and get
     // better compression by getting the same RGBG sequence in every line
@@ -75,15 +76,13 @@ RawImage Cr2Decoder::decodeRawInternal() {
     }
 
     mRaw->createData();
-    LJpegPlain *l = new LJpegPlain(mFile, mRaw);
+    LJpegPlain l(mFile, mRaw);
     try {
-      l->startDecoder(off, mFile->getSize()-off, 0, 0);
+      l.startDecoder(off, mFile->getSize()-off, 0, 0);
     } catch (IOException& e) {
       mRaw->setError(e.what());
     }
 
-    delete l;
-
     if(hints.find("double_line_ljpeg") != hints.end()) {
       // We now have a double width half height image we need to convert to the
       // normal format
@@ -118,6 +117,7 @@ RawImage Cr2Decoder::decodeRawInternal() {
           // We want uncorrected, but we store the table.
           mRaw->setTable(table, 4096, false);
         }
+        delete [] table;
       }
     }
 
@@ -146,9 +146,8 @@ RawImage Cr2Decoder::decodeRawInternal() {
       slice.offset = offsets[0].getInt();
       slice.count = counts[0].getInt();
       SOFInfo sof;
-      LJpegPlain *l = new LJpegPlain(mFile, mRaw);
-      l->getSOF(&sof, slice.offset, slice.count);
-      delete l;
+      LJpegPlain l(mFile, mRaw);
+      l.getSOF(&sof, slice.offset, slice.count);
       slice.w = sof.w * sof.cps;
       slice.h = sof.h;
       if (sof.cps == 4 && slice.w > slice.h * 4) {
@@ -230,14 +229,13 @@ RawImage Cr2Decoder::decodeRawInternal() {
   for (uint32 i = 0; i < slices.size(); i++) {
     Cr2Slice slice = slices[i];
     try {
-      LJpegPlain *l = new LJpegPlain(mFile, mRaw);
-      l->addSlices(s_width);
-      l->mUseBigtable = true;
-      l->mCanonFlipDim = flipDims;
-      l->mCanonDoubleHeight = doubleHeight;
-      l->mWrappedCr2Slices = wrappedCr2Slices;
-      l->startDecoder(slice.offset, slice.count, 0, offY);
-      delete l;
+      LJpegPlain l(mFile, mRaw);
+      l.addSlices(s_width);
+      l.mUseBigtable = true;
+      l.mCanonFlipDim = flipDims;
+      l.mCanonDoubleHeight = doubleHeight;
+      l.mWrappedCr2Slices = wrappedCr2Slices;
+      l.startDecoder(slice.offset, slice.count, 0, offY);
     } catch (RawDecoderException &e) {
       if (i == 0)
         throw;
