@@ -24,11 +24,6 @@
 
 namespace RawSpeed {
 
-#if defined(CHECKSIZE)
-#undef CHECKSIZE
-#endif
-#define CHECKSIZE(A) if (A > size) ThrowIOE("Error decoding DNG Slice (invalid size). File Corrupt")
-
 void *DecodeThread(void *_this) {
   DngDecoderThread* me = (DngDecoderThread*)_this;
   DngDecoderSlices* parent = me->parent;
@@ -37,7 +32,6 @@ void *DecodeThread(void *_this) {
   } catch (...) {
     parent->mRaw->setError("DNGDEcodeThread: Caught exception.");
   }
-  pthread_exit(NULL);
   return NULL;
 }
 
@@ -56,6 +50,15 @@ void DngDecoderSlices::addSlice(DngSliceElement slice) {
 }
 
 void DngDecoderSlices::startDecoding() {
+#ifdef NO_PTHREAD
+  DngDecoderThread t;
+  while (!slices.empty()) {
+    t.slices.push(slices.front());
+    slices.pop();
+  }
+  t.parent = this;
+  DecodeThread(&t);
+#else
   // Create threads
 
   nThreads = getThreadCount();
@@ -85,7 +88,7 @@ void DngDecoderSlices::startDecoding() {
     pthread_join(threads[i]->threadid, &status);
     delete(threads[i]);
   }
-
+#endif
 }
 
 #if JPEG_LIB_VERSION < 80
@@ -169,13 +172,10 @@ void DngDecoderSlices::decodeSlice(DngDecoderThread* t) {
       JSAMPARRAY buffer = (JSAMPARRAY)malloc(sizeof(JSAMPROW));
 
       try {
-        uint32 size = mFile->getSize();
         jpeg_create_decompress(&dinfo);
         dinfo.err = jpeg_std_error(&jerr);
         jerr.error_exit = my_error_throw;
-        CHECKSIZE(e.byteOffset);
-        CHECKSIZE(e.byteOffset+e.byteCount);
-        JPEG_MEMSRC(&dinfo, (unsigned char*)mFile->getData(e.byteOffset), e.byteCount);
+        JPEG_MEMSRC(&dinfo, (unsigned char*)mFile->getData(e.byteOffset, e.byteCount), e.byteCount);
 
         if (JPEG_HEADER_OK != jpeg_read_header(&dinfo, TRUE))
           ThrowRDE("DngDecoderSlices: Unable to read JPEG header");
