@@ -29,10 +29,16 @@ DngOpcodes::DngOpcodes(TiffEntry *entry)
   host = getHostEndianness();
   const uchar8* data = entry->getData();
   uint32 entry_size = entry->count;
-  uint32 opcode_count = getULong(&data[0]);
 
+  if (entry_size < 20)
+    ThrowRDE("DngOpcodes: Not enough bytes to read a single opcode");
+
+  uint32 opcode_count = getULong(&data[0]);
   int bytes_used = 4;
   for (uint32 i = 0; i < opcode_count; i++) {
+    if ((int)entry_size - bytes_used < 16)
+      ThrowRDE("DngOpcodes: Not enough bytes to read a new opcode");
+
     uint32 code = getULong(&data[bytes_used]);
     //uint32 version = getULong(&data[bytes_used+4]);
     uint32 flags = getULong(&data[bytes_used+8]);
@@ -76,8 +82,6 @@ DngOpcodes::DngOpcodes(TiffEntry *entry)
     if (opcode_used != expected_size)
       ThrowRDE("DngOpcodes: Inconsistent length of opcode");
     bytes_used += opcode_used;
-    if (bytes_used > (int)entry_size)
-      ThrowRDE("DngOpcodes: More codes than entry size (should be caught earlier)");
   }
 }
 
@@ -111,10 +115,10 @@ RawImage& DngOpcodes::applyOpCodes( RawImage &img )
 
 /***************** OpcodeFixBadPixelsConstant   ****************/
 
-OpcodeFixBadPixelsConstant::OpcodeFixBadPixelsConstant(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeFixBadPixelsConstant::OpcodeFixBadPixelsConstant(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 8)
-    ThrowRDE("OpcodeFixBadPixelsConstant: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeFixBadPixelsConstant: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mValue = getLong(&parameters[0]);
   // Bayer Phase not used
   *bytes_used = 8;
@@ -133,14 +137,14 @@ RawImage& OpcodeFixBadPixelsConstant::createOutput( RawImage &in )
   return in;
 }
 
-void OpcodeFixBadPixelsConstant::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeFixBadPixelsConstant::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   iPoint2D crop = in->getCropOffset();
   uint32 offset = crop.x | (crop.y << 16);
   vector<uint32> bad_pos;
-  for (int y = startY; y < endY; y ++) {
+  for (uint32 y = startY; y < endY; y++) {
     ushort16* src = (ushort16*)out->getData(0, y);
-    for (int x = 0; x < in->dim.x; x++) {
+    for (uint32 x = 0; x < (uint32)in->dim.x; x++) {
       if (src[x]== mValue) {
         bad_pos.push_back(offset + ((uint32)x | (uint32)y<<16));
       }
@@ -156,19 +160,20 @@ void OpcodeFixBadPixelsConstant::apply( RawImage &in, RawImage &out, int startY,
 
 /***************** OpcodeFixBadPixelsList   ****************/
 
-OpcodeFixBadPixelsList::OpcodeFixBadPixelsList( const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeFixBadPixelsList::OpcodeFixBadPixelsList( const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 12)
-    ThrowRDE("OpcodeFixBadPixelsList: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeFixBadPixelsList: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   // Skip phase - we don't care
-  int BadPointCount = getLong(&parameters[4]);
-  int BadRectCount = getLong(&parameters[8]);
-  bytes_used[0] = 12; 
-  if (12 + BadPointCount * 8 + BadRectCount * 16 > param_max_bytes)
-    ThrowRDE("OpcodeFixBadPixelsList: Ran out parameter space, only %d bytes left.", param_max_bytes);
+  uint64 BadPointCount = getULong(&parameters[4]);
+  uint64 BadRectCount = getULong(&parameters[8]);
+  bytes_used[0] = 12;
+
+  if (12 + BadPointCount * 8 + BadRectCount * 16 > (uint64) param_max_bytes)
+    ThrowRDE("OpcodeFixBadPixelsList: Ran out parameter space, only %u bytes left.", param_max_bytes);
 
   // Read points
-  for (int i = 0; i < BadPointCount; i++) {
+  for (uint64 i = 0; i < BadPointCount; i++) {
     uint32 BadPointRow = (uint32)getLong(&parameters[bytes_used[0]]);
     uint32 BadPointCol = (uint32)getLong(&parameters[bytes_used[0]+4]);
     bytes_used[0] += 8;
@@ -176,7 +181,7 @@ OpcodeFixBadPixelsList::OpcodeFixBadPixelsList( const uchar8* parameters, int pa
   }
 
   // Read rects
-  for (int i = 0; i < BadRectCount; i++) {
+  for (uint64 i = 0; i < BadRectCount; i++) {
     uint32 BadRectTop = (uint32)getLong(&parameters[bytes_used[0]]);
     uint32 BadRectLeft = (uint32)getLong(&parameters[bytes_used[0]+4]);
     uint32 BadRectBottom = (uint32)getLong(&parameters[bytes_used[0]]);
@@ -192,11 +197,11 @@ OpcodeFixBadPixelsList::OpcodeFixBadPixelsList( const uchar8* parameters, int pa
   }
 }
 
-void OpcodeFixBadPixelsList::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeFixBadPixelsList::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   iPoint2D crop = in->getCropOffset();
   uint32 offset = crop.x | (crop.y << 16);
-  for (vector<uint32>::iterator i=bad_pos.begin(); i != bad_pos.end(); i++) {
+  for (vector<uint32>::iterator i=bad_pos.begin(); i != bad_pos.end(); ++i) {
     uint32 pos = offset + (*i);
     out->mBadPixelPositions.push_back(pos);
   }
@@ -204,10 +209,10 @@ void OpcodeFixBadPixelsList::apply( RawImage &in, RawImage &out, int startY, int
 
  /***************** OpcodeTrimBounds   ****************/
 
-OpcodeTrimBounds::OpcodeTrimBounds(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeTrimBounds::OpcodeTrimBounds(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 16)
-    ThrowRDE("OpcodeTrimBounds: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeTrimBounds: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mTop = getLong(&parameters[0]);
   mLeft = getLong(&parameters[4]);
   mBottom = getLong(&parameters[8]);
@@ -215,7 +220,7 @@ OpcodeTrimBounds::OpcodeTrimBounds(const uchar8* parameters, int param_max_bytes
   *bytes_used = 16;
 }
 
-void OpcodeTrimBounds::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeTrimBounds::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   iRectangle2D crop(mLeft, mTop, mRight-mLeft, mBottom-mTop);
   out->subFrame(crop);
@@ -223,30 +228,30 @@ void OpcodeTrimBounds::apply( RawImage &in, RawImage &out, int startY, int endY
 
 /***************** OpcodeMapTable   ****************/
 
-OpcodeMapTable::OpcodeMapTable(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeMapTable::OpcodeMapTable(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 36)
-    ThrowRDE("OpcodeMapTable: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeMapTable: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mAoi.setAbsolute(getLong(&parameters[4]), getLong(&parameters[0]), getLong(&parameters[12]), getLong(&parameters[8]));
   mFirstPlane = getLong(&parameters[16]);
   mPlanes = getLong(&parameters[20]);
   mRowPitch = getLong(&parameters[24]);
   mColPitch = getLong(&parameters[28]);
-  if (mFirstPlane < 0)
-    ThrowRDE("OpcodeMapPolynomial: Negative first plane");
-  if (mPlanes <= 0)
-    ThrowRDE("OpcodeMapPolynomial: Negative number of planes");
-  if (mRowPitch <= 0 || mColPitch <= 0)
+  if (mPlanes == 0)
+    ThrowRDE("OpcodeMapPolynomial: Zero planes");
+  if (mRowPitch == 0 || mColPitch == 0)
     ThrowRDE("OpcodeMapPolynomial: Invalid Pitch");
 
   int tablesize = getLong(&parameters[32]);
   *bytes_used = 36;
 
+  if (tablesize <= 0)
+    ThrowRDE("OpcodeMapTable: Table size must be positive");
   if (tablesize > 65536)
     ThrowRDE("OpcodeMapTable: A map with more than 65536 entries not allowed");
 
-  if (param_max_bytes < 36 + (tablesize*2))
-    ThrowRDE("OpcodeMapPolynomial: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+  if (param_max_bytes < 36 + ((uint64)tablesize*2))
+    ThrowRDE("OpcodeMapPolynomial: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
 
   for (int i = 0; i <= 65535; i++)
   {
@@ -264,24 +269,24 @@ RawImage& OpcodeMapTable::createOutput( RawImage &in )
   if (in->getDataType() != TYPE_USHORT16)
     ThrowRDE("OpcodeMapTable: Only 16 bit images supported");
 
-  if (mFirstPlane > (int)in->getCpp())
+  if (mFirstPlane > in->getCpp())
     ThrowRDE("OpcodeMapTable: Not that many planes in actual image");
 
-  if (mFirstPlane+mPlanes > (int)in->getCpp())
+  if (mFirstPlane+mPlanes > in->getCpp())
     ThrowRDE("OpcodeMapTable: Not that many planes in actual image");
 
   return in;
 }
 
-void OpcodeMapTable::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeMapTable::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   int cpp = out->getCpp();
-  for (int y = startY; y < endY; y += mRowPitch) {
+  for (uint64 y = startY; y < endY; y += mRowPitch) {
     ushort16 *src = (ushort16*)out->getData(mAoi.getLeft(), y);
     // Add offset, so this is always first plane
     src+=mFirstPlane;
-    for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-      for (int p = 0; p < mPlanes; p++)
+    for (uint64 x = 0; x < (uint64) mAoi.getWidth(); x += mColPitch) {
+      for (uint64 p = 0; p < mPlanes; p++)
       {
         src[x*cpp+p] = mLookup[src[x*cpp+p]];
       }
@@ -293,20 +298,18 @@ void OpcodeMapTable::apply( RawImage &in, RawImage &out, int startY, int endY )
 
  /***************** OpcodeMapPolynomial   ****************/
 
-OpcodeMapPolynomial::OpcodeMapPolynomial(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeMapPolynomial::OpcodeMapPolynomial(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 36)
-    ThrowRDE("OpcodeMapPolynomial: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeMapPolynomial: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mAoi.setAbsolute(getLong(&parameters[4]), getLong(&parameters[0]), getLong(&parameters[12]), getLong(&parameters[8]));
   mFirstPlane = getLong(&parameters[16]);
   mPlanes = getLong(&parameters[20]);
   mRowPitch = getLong(&parameters[24]);
   mColPitch = getLong(&parameters[28]);
-  if (mFirstPlane < 0)
-    ThrowRDE("OpcodeMapPolynomial: Negative first plane");
-  if (mPlanes <= 0)
-    ThrowRDE("OpcodeMapPolynomial: Negative number of planes");
-  if (mRowPitch <= 0 || mColPitch <= 0)
+  if (mPlanes == 0)
+    ThrowRDE("OpcodeMapPolynomial: Zero planes");
+  if (mRowPitch == 0 || mColPitch == 0)
     ThrowRDE("OpcodeMapPolynomial: Invalid Pitch");
 
   mDegree = getLong(&parameters[32]);
@@ -314,8 +317,8 @@ OpcodeMapPolynomial::OpcodeMapPolynomial(const uchar8* parameters, int param_max
   if (mDegree > 8)
     ThrowRDE("OpcodeMapPolynomial: A polynomial with more than 8 degrees not allowed");
   if (param_max_bytes < 36 + (mDegree*8))
-    ThrowRDE("OpcodeMapPolynomial: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
-  for (int i = 0; i <= mDegree; i++)
+    ThrowRDE("OpcodeMapPolynomial: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
+  for (uint64 i = 0; i <= mDegree; i++)
     mCoefficient[i] = getDouble(&parameters[36+8*i]);
   *bytes_used += 8*mDegree+8;
   mFlags = MultiThreaded | PureLookup;
@@ -327,10 +330,10 @@ RawImage& OpcodeMapPolynomial::createOutput( RawImage &in )
   if (in->getDataType() != TYPE_USHORT16)
     ThrowRDE("OpcodeMapPolynomial: Only 16 bit images supported");
 
-  if (mFirstPlane > (int)in->getCpp())
+  if (mFirstPlane > in->getCpp())
     ThrowRDE("OpcodeMapPolynomial: Not that many planes in actual image");
 
-  if (mFirstPlane+mPlanes > (int)in->getCpp())
+  if (mFirstPlane+mPlanes > in->getCpp())
     ThrowRDE("OpcodeMapPolynomial: Not that many planes in actual image");
 
   // Create lookup
@@ -338,22 +341,22 @@ RawImage& OpcodeMapPolynomial::createOutput( RawImage &in )
   {
     double in_val = (double)i/65536.0;
     double val = mCoefficient[0];
-    for (int j = 1; j <= mDegree; j++)
+    for (uint64 j = 1; j <= mDegree; j++)
       val += mCoefficient[j] * pow(in_val, (double)(j));
     mLookup[i] = clampbits((int)(val*65535.5), 16);
   }
   return in;
 }
 
-void OpcodeMapPolynomial::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeMapPolynomial::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   int cpp = out->getCpp();
-  for (int y = startY; y < endY; y += mRowPitch) {
+  for (uint64 y = startY; y < endY; y += mRowPitch) {
     ushort16 *src = (ushort16*)out->getData(mAoi.getLeft(), y);
     // Add offset, so this is always first plane
     src+=mFirstPlane;
-    for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-      for (int p = 0; p < mPlanes; p++)
+    for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+      for (uint64 p = 0; p < mPlanes; p++)
       {
         src[x*cpp+p] = mLookup[src[x*cpp+p]];
       }
@@ -363,30 +366,28 @@ void OpcodeMapPolynomial::apply( RawImage &in, RawImage &out, int startY, int en
 
 /***************** OpcodeDeltaPerRow   ****************/
 
-OpcodeDeltaPerRow::OpcodeDeltaPerRow(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeDeltaPerRow::OpcodeDeltaPerRow(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 36)
-    ThrowRDE("OpcodeDeltaPerRow: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeDeltaPerRow: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mAoi.setAbsolute(getLong(&parameters[4]), getLong(&parameters[0]), getLong(&parameters[12]), getLong(&parameters[8]));
   mFirstPlane = getLong(&parameters[16]);
   mPlanes = getLong(&parameters[20]);
   mRowPitch = getLong(&parameters[24]);
   mColPitch = getLong(&parameters[28]);
-  if (mFirstPlane < 0)
-    ThrowRDE("OpcodeDeltaPerRow: Negative first plane");
-  if (mPlanes <= 0)
-    ThrowRDE("OpcodeDeltaPerRow: Negative number of planes");
-  if (mRowPitch <= 0 || mColPitch <= 0)
+  if (mPlanes == 0)
+    ThrowRDE("OpcodeDeltaPerRow: Zero planes");
+  if (mRowPitch == 0 || mColPitch == 0)
     ThrowRDE("OpcodeDeltaPerRow: Invalid Pitch");
 
   mCount = getLong(&parameters[32]);
   *bytes_used = 36;
   if (param_max_bytes < 36 + (mCount*4))
-    ThrowRDE("OpcodeDeltaPerRow: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
-  if (mAoi.getHeight() != mCount)
-    ThrowRDE("OpcodeDeltaPerRow: Element count (%d) does not match height of area (%d).", mCount, mAoi.getHeight());
+    ThrowRDE("OpcodeDeltaPerRow: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
+  if ((uint64)mAoi.getHeight() != mCount)
+    ThrowRDE("OpcodeDeltaPerRow: Element count (%llu) does not match height of area (%d.", mCount, mAoi.getHeight());
 
-  for (int i = 0; i <= mCount; i++)
+  for (uint64 i = 0; i < mCount; i++)
     mDelta[i] = getFloat(&parameters[36+4*i]);
   *bytes_used += 4*mCount;
   mFlags = MultiThreaded;
@@ -395,26 +396,26 @@ OpcodeDeltaPerRow::OpcodeDeltaPerRow(const uchar8* parameters, int param_max_byt
 
 RawImage& OpcodeDeltaPerRow::createOutput( RawImage &in )
 {
-  if (mFirstPlane > (int)in->getCpp())
+  if (mFirstPlane > in->getCpp())
     ThrowRDE("OpcodeDeltaPerRow: Not that many planes in actual image");
 
-  if (mFirstPlane+mPlanes > (int)in->getCpp())
+  if (mFirstPlane+mPlanes > in->getCpp())
     ThrowRDE("OpcodeDeltaPerRow: Not that many planes in actual image");
 
   return in;
 }
 
-void OpcodeDeltaPerRow::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeDeltaPerRow::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   if (in->getDataType() == TYPE_USHORT16) {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       ushort16 *src = (ushort16*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
       int delta = (int)(65535.0f * mDelta[y]);
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = clampbits(16,delta + src[x*cpp+p]);
         }
@@ -422,13 +423,13 @@ void OpcodeDeltaPerRow::apply( RawImage &in, RawImage &out, int startY, int endY
     }
   } else {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       float *src = (float*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
       float delta = mDelta[y];
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = delta + src[x*cpp+p];
         }
@@ -439,30 +440,28 @@ void OpcodeDeltaPerRow::apply( RawImage &in, RawImage &out, int startY, int endY
 
 /***************** OpcodeDeltaPerCol   ****************/
 
-OpcodeDeltaPerCol::OpcodeDeltaPerCol(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeDeltaPerCol::OpcodeDeltaPerCol(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 36)
-    ThrowRDE("OpcodeDeltaPerCol: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeDeltaPerCol: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mAoi.setAbsolute(getLong(&parameters[4]), getLong(&parameters[0]), getLong(&parameters[12]), getLong(&parameters[8]));
   mFirstPlane = getLong(&parameters[16]);
   mPlanes = getLong(&parameters[20]);
   mRowPitch = getLong(&parameters[24]);
   mColPitch = getLong(&parameters[28]);
-  if (mFirstPlane < 0)
-    ThrowRDE("OpcodeDeltaPerCol: Negative first plane");
-  if (mPlanes <= 0)
-    ThrowRDE("OpcodeDeltaPerCol: Negative number of planes");
-  if (mRowPitch <= 0 || mColPitch <= 0)
+  if (mPlanes == 0)
+    ThrowRDE("OpcodeDeltaPerCol: Zero planes");
+  if (mRowPitch == 0 || mColPitch == 0)
     ThrowRDE("OpcodeDeltaPerCol: Invalid Pitch");
 
   mCount = getLong(&parameters[32]);
   *bytes_used = 36;
   if (param_max_bytes < 36 + (mCount*4))
-    ThrowRDE("OpcodeDeltaPerCol: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
-  if (mAoi.getWidth() != mCount)
-    ThrowRDE("OpcodeDeltaPerRow: Element count (%d) does not match width of area (%d).", mCount, mAoi.getWidth());
+    ThrowRDE("OpcodeDeltaPerCol: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
+  if ((uint64)mAoi.getWidth() != mCount)
+    ThrowRDE("OpcodeDeltaPerRow: Element count (%llu) does not match width of area (%d).", mCount, mAoi.getWidth());
 
-  for (int i = 0; i <= mCount; i++)
+  for (uint64 i = 0; i < mCount; i++)
     mDelta[i] = getFloat(&parameters[36+4*i]);
   *bytes_used += 4*mCount;
   mFlags = MultiThreaded;
@@ -479,10 +478,10 @@ OpcodeDeltaPerCol::~OpcodeDeltaPerCol( void )
 
 RawImage& OpcodeDeltaPerCol::createOutput( RawImage &in )
 {
-  if (mFirstPlane > (int)in->getCpp())
+  if (mFirstPlane > in->getCpp())
     ThrowRDE("OpcodeDeltaPerCol: Not that many planes in actual image");
 
-  if (mFirstPlane+mPlanes > (int)in->getCpp())
+  if (mFirstPlane+mPlanes > in->getCpp())
     ThrowRDE("OpcodeDeltaPerCol: Not that many planes in actual image");
 
   if (in->getDataType() == TYPE_USHORT16) {
@@ -496,16 +495,16 @@ RawImage& OpcodeDeltaPerCol::createOutput( RawImage &in )
   return in;
 }
 
-void OpcodeDeltaPerCol::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeDeltaPerCol::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   if (in->getDataType() == TYPE_USHORT16) {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       ushort16 *src = (ushort16*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = clampbits(16, mDeltaX[x] + src[x*cpp+p]);
         }
@@ -513,12 +512,12 @@ void OpcodeDeltaPerCol::apply( RawImage &in, RawImage &out, int startY, int endY
     }
   } else {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       float *src = (float*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = mDelta[x] + src[x*cpp+p];
         }
@@ -529,30 +528,28 @@ void OpcodeDeltaPerCol::apply( RawImage &in, RawImage &out, int startY, int endY
 
 /***************** OpcodeScalePerRow   ****************/
 
-OpcodeScalePerRow::OpcodeScalePerRow(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeScalePerRow::OpcodeScalePerRow(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 36)
-    ThrowRDE("OpcodeScalePerRow: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeScalePerRow: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mAoi.setAbsolute(getLong(&parameters[4]), getLong(&parameters[0]), getLong(&parameters[12]), getLong(&parameters[8]));
   mFirstPlane = getLong(&parameters[16]);
   mPlanes = getLong(&parameters[20]);
   mRowPitch = getLong(&parameters[24]);
   mColPitch = getLong(&parameters[28]);
-  if (mFirstPlane < 0)
-    ThrowRDE("OpcodeScalePerRow: Negative first plane");
-  if (mPlanes <= 0)
-    ThrowRDE("OpcodeScalePerRow: Negative number of planes");
-  if (mRowPitch <= 0 || mColPitch <= 0)
+  if (mPlanes == 0)
+    ThrowRDE("OpcodeScalePerRow: Zero planes");
+  if (mRowPitch == 0 || mColPitch == 0)
     ThrowRDE("OpcodeScalePerRow: Invalid Pitch");
 
   mCount = getLong(&parameters[32]);
   *bytes_used = 36;
   if (param_max_bytes < 36 + (mCount*4))
-    ThrowRDE("OpcodeScalePerRow: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
-  if (mAoi.getHeight() != mCount)
-    ThrowRDE("OpcodeScalePerRow: Element count (%d) does not match height of area (%d).", mCount, mAoi.getHeight());
+    ThrowRDE("OpcodeScalePerRow: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
+  if ((uint64)mAoi.getHeight() != mCount)
+    ThrowRDE("OpcodeScalePerRow: Element count (%llu) does not match height of area (%d).", mCount, mAoi.getHeight());
 
-  for (int i = 0; i <= mCount; i++)
+  for (uint64 i = 0; i < mCount; i++)
     mDelta[i] = getFloat(&parameters[36+4*i]);
   *bytes_used += 4*mCount;
   mFlags = MultiThreaded;
@@ -561,26 +558,26 @@ OpcodeScalePerRow::OpcodeScalePerRow(const uchar8* parameters, int param_max_byt
 
 RawImage& OpcodeScalePerRow::createOutput( RawImage &in )
 {
-  if (mFirstPlane > (int)in->getCpp())
+  if (mFirstPlane > in->getCpp())
     ThrowRDE("OpcodeScalePerRow: Not that many planes in actual image");
 
-  if (mFirstPlane+mPlanes > (int)in->getCpp())
+  if (mFirstPlane+mPlanes > in->getCpp())
     ThrowRDE("OpcodeScalePerRow: Not that many planes in actual image");
 
   return in;
 }
 
-void OpcodeScalePerRow::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeScalePerRow::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   if (in->getDataType() == TYPE_USHORT16) {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       ushort16 *src = (ushort16*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
       int delta = (int)(1024.0f * mDelta[y]);
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = clampbits(16,(delta * src[x*cpp+p] + 512) >> 10);
         }
@@ -588,13 +585,13 @@ void OpcodeScalePerRow::apply( RawImage &in, RawImage &out, int startY, int endY
     }
   } else {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       float *src = (float*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
       float delta = mDelta[y];
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = delta * src[x*cpp+p];
         }
@@ -605,30 +602,28 @@ void OpcodeScalePerRow::apply( RawImage &in, RawImage &out, int startY, int endY
 
 /***************** OpcodeScalePerCol   ****************/
 
-OpcodeScalePerCol::OpcodeScalePerCol(const uchar8* parameters, int param_max_bytes, uint32 *bytes_used )
+OpcodeScalePerCol::OpcodeScalePerCol(const uchar8* parameters, uint32 param_max_bytes, uint32 *bytes_used )
 {
   if (param_max_bytes < 36)
-    ThrowRDE("OpcodeScalePerCol: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
+    ThrowRDE("OpcodeScalePerCol: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
   mAoi.setAbsolute(getLong(&parameters[4]), getLong(&parameters[0]), getLong(&parameters[12]), getLong(&parameters[8]));
   mFirstPlane = getLong(&parameters[16]);
   mPlanes = getLong(&parameters[20]);
   mRowPitch = getLong(&parameters[24]);
   mColPitch = getLong(&parameters[28]);
-  if (mFirstPlane < 0)
-    ThrowRDE("OpcodeScalePerCol: Negative first plane");
-  if (mPlanes <= 0)
-    ThrowRDE("OpcodeScalePerCol: Negative number of planes");
-  if (mRowPitch <= 0 || mColPitch <= 0)
+  if (mPlanes == 0)
+    ThrowRDE("OpcodeScalePerCol: Zero planes");
+  if (mRowPitch == 0 || mColPitch == 0)
     ThrowRDE("OpcodeScalePerCol: Invalid Pitch");
 
   mCount = getLong(&parameters[32]);
   *bytes_used = 36;
   if (param_max_bytes < 36 + (mCount*4))
-    ThrowRDE("OpcodeScalePerCol: Not enough data to read parameters, only %d bytes left.", param_max_bytes);
-  if (mAoi.getWidth() != mCount)
-    ThrowRDE("OpcodeScalePerCol: Element count (%d) does not match width of area (%d).", mCount, mAoi.getWidth());
+    ThrowRDE("OpcodeScalePerCol: Not enough data to read parameters, only %u bytes left.", param_max_bytes);
+  if ((uint64)mAoi.getWidth() != mCount)
+    ThrowRDE("OpcodeScalePerCol: Element count (%llu) does not match width of area (%d).", mCount, mAoi.getWidth());
 
-  for (int i = 0; i <= mCount; i++)
+  for (uint64 i = 0; i < mCount; i++)
     mDelta[i] = getFloat(&parameters[36+4*i]);
   *bytes_used += 4*mCount;
   mFlags = MultiThreaded;
@@ -645,10 +640,10 @@ OpcodeScalePerCol::~OpcodeScalePerCol( void )
 
 RawImage& OpcodeScalePerCol::createOutput( RawImage &in )
 {
-  if (mFirstPlane > (int)in->getCpp())
+  if (mFirstPlane > in->getCpp())
     ThrowRDE("OpcodeScalePerCol: Not that many planes in actual image");
 
-  if (mFirstPlane+mPlanes > (int)in->getCpp())
+  if (mFirstPlane+mPlanes > in->getCpp())
     ThrowRDE("OpcodeScalePerCol: Not that many planes in actual image");
 
   if (in->getDataType() == TYPE_USHORT16) {
@@ -662,16 +657,16 @@ RawImage& OpcodeScalePerCol::createOutput( RawImage &in )
   return in;
 }
 
-void OpcodeScalePerCol::apply( RawImage &in, RawImage &out, int startY, int endY )
+void OpcodeScalePerCol::apply( RawImage &in, RawImage &out, uint32 startY, uint32 endY )
 {
   if (in->getDataType() == TYPE_USHORT16) {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       ushort16 *src = (ushort16*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = clampbits(16, (mDeltaX[x] * src[x*cpp+p] + 512) >> 10);
         }
@@ -679,12 +674,12 @@ void OpcodeScalePerCol::apply( RawImage &in, RawImage &out, int startY, int endY
     }
   } else {
     int cpp = out->getCpp();
-    for (int y = startY; y < endY; y += mRowPitch) {
+    for (uint64 y = startY; y < endY; y += mRowPitch) {
       float *src = (float*)out->getData(mAoi.getLeft(), y);
       // Add offset, so this is always first plane
       src+=mFirstPlane;
-      for (int x = 0; x < mAoi.getWidth(); x += mColPitch) {
-        for (int p = 0; p < mPlanes; p++)
+      for (uint64 x = 0; x < (uint64)mAoi.getWidth(); x += mColPitch) {
+        for (uint64 p = 0; p < mPlanes; p++)
         {
           src[x*cpp+p] = mDelta[x] * src[x*cpp+p];
         }
