@@ -107,15 +107,15 @@ LJpegDecompressor::~LJpegDecompressor(void) {
 }
 
 void LJpegDecompressor::getSOF(SOFInfo* sof, uint32 offset, uint32 size) {
-  if (!mFile->isValid(offset + size - 1))
+  if (!mFile->isValid(offset, size))
     ThrowRDE("LJpegDecompressor::getSOF: Start offset plus size is longer than file. Truncated file.");
   try {
     Endianness host_endian = getHostEndianness();
     // JPEG is big endian
     if (host_endian == big)
-      input = new ByteStream(mFile->getData(offset), size);
+      input = new ByteStream(mFile, offset, size);
     else 
-      input = new ByteStreamSwap(mFile->getData(offset), size);
+      input = new ByteStreamSwap(mFile, offset, size);
 
     if (getNextMarker(false) != M_SOI)
       ThrowRDE("LJpegDecompressor::getSOF: Image did not start with SOI. Probably not an LJPEG");
@@ -137,7 +137,7 @@ void LJpegDecompressor::getSOF(SOFInfo* sof, uint32 offset, uint32 size) {
 }
 
 void LJpegDecompressor::startDecoder(uint32 offset, uint32 size, uint32 offsetX, uint32 offsetY) {
-  if (!mFile->isValid(offset + size - 1))
+  if (!mFile->isValid(offset, size))
     ThrowRDE("LJpegDecompressor::startDecoder: Start offset plus size is longer than file. Truncated file.");
   if ((int)offsetX >= mRaw->dim.x)
     ThrowRDE("LJpegDecompressor::startDecoder: X offset outside of image");
@@ -150,9 +150,9 @@ void LJpegDecompressor::startDecoder(uint32 offset, uint32 size, uint32 offsetX,
     Endianness host_endian = getHostEndianness();
     // JPEG is big endian
     if (host_endian == big)
-      input = new ByteStream(mFile->getData(offset), size);
+      input = new ByteStream(mFile, offset, size);
     else 
-      input = new ByteStreamSwap(mFile->getData(offset), size);
+      input = new ByteStreamSwap(mFile, offset, size);
 
     if (getNextMarker(false) != M_SOI)
       ThrowRDE("LJpegDecompressor::startDecoder: Image did not start with SOI. Probably not an LJPEG");
@@ -472,7 +472,7 @@ void LJpegDecompressor::createBigTable(HuffmanTable *htbl) {
   if (!htbl->bigTable)
     htbl->bigTable = (int*)_aligned_malloc(size * sizeof(int), 16);
   if (!htbl->bigTable)
-	ThrowRDE("Out of memory, failed to allocate %lu bytes", size*sizeof(int));
+	ThrowRDE("Out of memory, failed to allocate %zu bytes", size*sizeof(int));
   for (uint32 i = 0; i < size; i++) {
     ushort16 input = i << 2; // Calculate input value
     int code = input >> 8;   // Get 8 bits
