@@ -515,8 +515,10 @@ bool RawDecoder::checkCameraSupported(CameraMetaData *meta, string make, string
   mRaw->metadata.model = model;
   Camera* cam = meta->getCamera(make, model, mode);
   if (!cam) {
-    if (mode.length() == 0)
-      writeLog(DEBUG_PRIO_WARNING, "Unable to find camera in database: %s %s %s\n", make.c_str(), model.c_str(), mode.c_str());
+    writeLog(DEBUG_PRIO_WARNING, "Unable to find camera in database: '%s' '%s' "
+                                 "'%s'\nPlease consider providing samples on "
+                                 "<https://raw.pixls.us/>, thanks!\n",
+             make.c_str(), model.c_str(), mode.c_str());
 
     if (failOnUnknown)
       ThrowRDE("Camera '%s' '%s', mode '%s' not supported, and not allowed to guess. Sorry.", make.c_str(), model.c_str(), mode.c_str());
@@ -542,7 +544,10 @@ void RawDecoder::setMetaData(CameraMetaData *meta, string make, string model, st
   Camera *cam = meta->getCamera(make, model, mode);
   if (!cam) {
     writeLog(DEBUG_PRIO_INFO, "ISO:%d\n", iso_speed);
-    writeLog(DEBUG_PRIO_WARNING, "Unable to find camera in database: '%s' '%s' '%s'\nPlease upload file to ftp.rawstudio.org, thanks!\n", make.c_str(), model.c_str(), mode.c_str());
+    writeLog(DEBUG_PRIO_WARNING, "Unable to find camera in database: '%s' '%s' "
+                                 "'%s'\nPlease consider providing samples on "
+                                 "<https://raw.pixls.us/>, thanks!\n",
+             make.c_str(), model.c_str(), mode.c_str());
 
     if (failOnUnknown)
       ThrowRDE("Camera '%s' '%s', mode '%s' not supported, and not allowed to guess. Sorry.", make.c_str(), model.c_str(), mode.c_str());
