@@ -35,18 +35,30 @@ TiffEntry::TiffEntry() {
 TiffEntry::TiffEntry(FileMap* f, uint32 offset, uint32 up_offset) {
   parent_offset = up_offset;
   own_data = NULL;
+  empty_data = 0;
   file = f;
-  unsigned short* p = (unsigned short*)f->getData(offset);
-  tag = (TiffTag)p[0];
-  type = (TiffDataType)p[1];
-  count = *(int*)f->getData(offset + 4);
-  if (type > 13)
-    ThrowTPE("Error reading TIFF structure. Unknown Type 0x%x encountered.", type);
-  uint32 bytesize = count << datashifts[type];
-  if (bytesize <= 4) {
-    data = f->getDataWrt(offset + 8);
-  } else { // offset
-    data_offset = *(uint32*)f->getData(offset + 8);
+  type = TIFF_UNDEFINED;  // We set type to undefined to avoid debug assertion errors.
+
+  const uchar8 *temp_data = (const uchar8 *)f->getData(offset, 8);
+  tag = (TiffTag) get2LE(temp_data, 0);
+  const ushort16 numType = get2LE(temp_data, 2);
+  count = get4LE(temp_data,4);
+
+  if (numType > 13)
+    ThrowTPE("Error reading TIFF structure. Unknown Type 0x%x encountered.", numType);
+
+  type = (TiffDataType) numType;
+
+  bytesize = (uint64)count << datashifts[type];
+  if (bytesize > UINT32_MAX)
+    ThrowTPE("TIFF entry is supposedly %llu bytes", bytesize);
+
+  if (bytesize == 0) // Better return empty than NULL-dereference later
+    data = (uchar8 *) &empty_data;
+  else if (bytesize <= 4)
+    data = f->getDataWrt(offset + 8, bytesize);
+  else { // offset
+    data_offset = get4LE(f->getData(offset+8, 4),0);
     fetchData();
   }
 #ifdef _DEBUG
@@ -61,14 +73,12 @@ TiffEntry::TiffEntry(FileMap* f, uint32 offset, uint32 up_offset) {
 }
 
 void TiffEntry::fetchData() {
-  FileMap *f = file; // CHECKSIZE uses f
   if(file) {
-    uint32 bytesize = count << datashifts[type];
-    CHECKSIZE(data_offset + bytesize);
-    data = file->getDataWrt(data_offset);
+    data = file->getDataWrt(data_offset, bytesize);
   }
 }
 
+
 TiffEntry::TiffEntry(TiffTag _tag, TiffDataType _type, uint32 _count, const uchar8* _data )
 {
   file = NULL;
@@ -77,8 +87,8 @@ TiffEntry::TiffEntry(TiffTag _tag, TiffDataType _type, uint32 _count, const ucha
   type = _type;
   count = _count;
   data_offset = -1; // Set nonsense value in case someone tries to use it
+  bytesize = (size_t)_count << (size_t)datashifts[_type];
   if (NULL == _data) {
-    uint32 bytesize = _count << datashifts[_type];
     own_data = new uchar8[bytesize];
     memset(own_data,0,bytesize);
     data = own_data;
@@ -106,67 +116,105 @@ bool TiffEntry::isInt() {
   return (type == TIFF_LONG || type == TIFF_SHORT || type ==  TIFF_BYTE);
 }
 
-unsigned int TiffEntry::getInt() {
-  if (!(type == TIFF_LONG || type == TIFF_SHORT || type == TIFF_BYTE || type == TIFF_OFFSET))
-    ThrowTPE("TIFF, getInt: Wrong type 0x%x encountered. Expected Long, Short or Byte", type);
-  if (type == TIFF_BYTE)
-    return getByte();
-  if (type == TIFF_SHORT)
-    return getShort();
-  return (uint32)data[3] << 24 | (uint32)data[2] << 16 | (uint32)data[1] << 8 | (uint32)data[0];
-}
-
-unsigned short TiffEntry::getShort() {
-  if (type != TIFF_SHORT)
-    ThrowTPE("TIFF, getShort: Wrong type 0x%x encountered. Expected Short", type);
-  return ((ushort16)data[1] << 8) | (ushort16)data[0];
-}
-
-const uint32* TiffEntry::getIntArray() {
-  if (type != TIFF_LONG && type != TIFF_SLONG && type != TIFF_RATIONAL && type != TIFF_SRATIONAL && type != TIFF_UNDEFINED && type != TIFF_OFFSET)
-    ThrowTPE("TIFF, getIntArray: Wrong type 0x%x encountered. Expected Long", type);
-  return (uint32*)&data[0];
-}
-
-const ushort16* TiffEntry::getShortArray() {
-  if (!(type == TIFF_SHORT || type == TIFF_UNDEFINED))
-    ThrowTPE("TIFF, getShortArray: Wrong type 0x%x encountered. Expected Short", type);
-  return (ushort16*)&data[0];
-}
-
-const short16* TiffEntry::getSignedShortArray() {
-  if (!(type == TIFF_SSHORT))
-    ThrowTPE("TIFF, getShortArray: Wrong type 0x%x encountered. Expected Signed Short", type);
-  return (short16*)&data[0];
-}
-
-uchar8 TiffEntry::getByte() {
+uchar8 TiffEntry::getByte(uint32 num) {
   if (type != TIFF_BYTE)
-    ThrowTPE("TIFF, getByte: Wrong type 0x%x encountered. Expected Byte", type);
-  return data[0];
+    ThrowTPE("TIFF, getByte: Wrong type %u encountered. Expected Byte on 0x%x", type, tag);
+
+  if (num >= bytesize)
+    ThrowTPE("TIFF, getByte: Trying to read out of bounds");
+
+  return data[num];
+}
+
+ushort16 TiffEntry::getShort(uint32 num) {
+  if (type != TIFF_SHORT && type != TIFF_UNDEFINED)
+    ThrowTPE("TIFF, getShort: Wrong type %u encountered. Expected Short or Undefined on 0x%x", type, tag);
+
+  if (num*2+1 >= bytesize)
+    ThrowTPE("TIFF, getShort: Trying to read out of bounds");
+
+  return get2LE(data, num*2);
+}
+
+short16 TiffEntry::getSShort(uint32 num) {
+  if (type != TIFF_SSHORT && type != TIFF_UNDEFINED)
+    ThrowTPE("TIFF, getSShort: Wrong type %u encountered. Expected Short or Undefined on 0x%x", type, tag);
+
+  if (num*2+1 >= bytesize)
+    ThrowTPE("TIFF, getSShort: Trying to read out of bounds");
+
+  return (short16) get2LE(data, num*2);
+}
+
+uint32 TiffEntry::getInt(uint32 num) {
+  if (type == TIFF_SHORT) return getShort(num);
+  if (!(type == TIFF_LONG || type == TIFF_OFFSET || type == TIFF_BYTE || type == TIFF_UNDEFINED || type == TIFF_RATIONAL || type == TIFF_SRATIONAL))
+    ThrowTPE("TIFF, getInt: Wrong type %u encountered. Expected Long, Offset, Rational or Undefined on 0x%x", type, tag);
+
+  if (num*4+3 >= bytesize)
+    ThrowTPE("TIFF, getInt: Trying to read out of bounds");
+
+  return get4LE(data, num*4);
+}
+
+int32 TiffEntry::getSInt(uint32 num) {
+  if (type == TIFF_SSHORT) return getSShort(num);
+  if (!(type == TIFF_SLONG || type == TIFF_UNDEFINED))
+    ThrowTPE("TIFF, getSInt: Wrong type %u encountered. Expected SLong or Undefined on 0x%x", type, tag);
+
+  if (num*4+3 >= bytesize)
+    ThrowTPE("TIFF, getSInt: Trying to read out of bounds");
+
+  return get4LE(data, num*4);
+}
+
+void TiffEntry::getShortArray(ushort16 *array, uint32 num) {
+  for (uint32 i = 0; i < num; i++)
+    array[i] = getShort(i);
+}
+
+void TiffEntry::getIntArray(uint32 *array, uint32 num) {
+  for (uint32 i = 0; i < num; i++)
+    array[i] = getInt(i);
+}
+
+void TiffEntry::getFloatArray(float *array, uint32 num) {
+  for (uint32 i = 0; i < num; i++)
+    array[i] = getFloat(i);
 }
 
 bool TiffEntry::isFloat() {
-  return (type == TIFF_FLOAT || type == TIFF_DOUBLE || type == TIFF_RATIONAL || type == TIFF_SRATIONAL || type == TIFF_LONG || type == TIFF_SHORT);
+  return  (type == TIFF_FLOAT || type == TIFF_DOUBLE || type == TIFF_RATIONAL || 
+           type == TIFF_SRATIONAL || type == TIFF_LONG || type == TIFF_SLONG || 
+           type == TIFF_SHORT || type == TIFF_SSHORT);
 }
 
-float TiffEntry::getFloat() {
-  if (!(type == TIFF_FLOAT || type == TIFF_DOUBLE || type == TIFF_RATIONAL || type == TIFF_SRATIONAL || type == TIFF_LONG || type == TIFF_SHORT))
-    ThrowTPE("TIFF, getFloat: Wrong type 0x%x encountered. Expected Float", type);
+float TiffEntry::getFloat(uint32 num) {
+  if (!isFloat())
+    ThrowTPE("TIFF, getFloat: Wrong type 0x%x encountered. Expected Float or something convertible on 0x%x", type, tag);
+
   if (type == TIFF_DOUBLE) {
-    return (float)*(double*)&data[0];
+    if (num*8+7 >= bytesize)
+      ThrowTPE("TIFF, getFloat: Trying to read out of bounds");
+    return (float) get8LE(data, num*8);
   } else if (type == TIFF_FLOAT) {
-    return *(float*)&data[0];
+    if (num*4+3 >= bytesize)
+      ThrowTPE("TIFF, getFloat: Trying to read out of bounds");
+    return (float) get4LE(data, num*4);
   } else if (type == TIFF_LONG || type == TIFF_SHORT) {
-    return (float)getInt();
+    return (float)getInt(num);
+  } else if (type == TIFF_SLONG || type == TIFF_SSHORT) {
+    return (float)getSInt(num);
   } else if (type == TIFF_RATIONAL) {
-    const unsigned int* t = getIntArray();
-    if (t[1])
-      return (float)t[0]/t[1];
+    uint32 a = getInt(num*2);
+    uint32 b = getInt(num*2+1);
+    if (b)
+      return (float) a/b;
   } else if (type == TIFF_SRATIONAL) {
-    const int* t = (const int*)getIntArray();
-    if (t[1])
-      return (float)t[0]/t[1];
+    int a = (int) getInt(num*2);
+    int b = (int) getInt(num*2+1);
+    if (b)
+      return (float) a/b;
   }
   return 0.0f;
 }
@@ -174,6 +222,10 @@ float TiffEntry::getFloat() {
 string TiffEntry::getString() {
   if (type != TIFF_ASCII && type != TIFF_BYTE)
     ThrowTPE("TIFF, getString: Wrong type 0x%x encountered. Expected Ascii or Byte", type);
+
+  if (count == 0)
+    return string("");
+
   if (!own_data) {
     own_data = new uchar8[count];
     memcpy(own_data, data, count);
@@ -210,7 +262,6 @@ void TiffEntry::setData( const void *in_data, uint32 byte_count )
 uchar8* TiffEntry::getDataWrt()
 {
   if (!own_data) {
-    uint32 bytesize = count << datashifts[type];
     own_data = new uchar8[bytesize];
     memcpy(own_data, data, bytesize);
   }
