@@ -16,16 +16,16 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "common/darktable.h"
 #include "gui/accelerators.h"
-#include "control/control.h"
+#include "common/darktable.h"
 #include "common/debug.h"
+#include "control/control.h"
 #include "develop/blend.h"
 
 #include "bauhaus/bauhaus.h"
 
-#include <gtk/gtk.h>
 #include <assert.h>
+#include <gtk/gtk.h>
 
 void dt_accel_path_global(char *s, size_t n, const char *path)
 {
@@ -268,7 +268,7 @@ static void _connect_local_accel(dt_iop_module_t *module, dt_accel_t *accel)
   module->accel_closures_local = g_slist_prepend(module->accel_closures_local, accel);
 }
 
-void dt_accel_connect_iop(dt_iop_module_t *module, const gchar *path, GClosure *closure)
+dt_accel_t *dt_accel_connect_iop(dt_iop_module_t *module, const gchar *path, GClosure *closure)
 {
   dt_accel_t *accel = NULL;
   gchar accel_path[256];
@@ -289,20 +289,23 @@ void dt_accel_connect_iop(dt_iop_module_t *module, const gchar *path, GClosure *
     gtk_accel_group_connect_by_path(darktable.control->accelerators, accel_path, closure);
     module->accel_closures = g_slist_prepend(module->accel_closures, accel);
   }
+
+  return accel;
 }
 
-void dt_accel_connect_lib(dt_lib_module_t *module, const gchar *path, GClosure *closure)
+dt_accel_t *dt_accel_connect_lib(dt_lib_module_t *module, const gchar *path, GClosure *closure)
 {
   gchar accel_path[256];
   dt_accel_path_lib(accel_path, sizeof(accel_path), module->plugin_name, path);
   gtk_accel_group_connect_by_path(darktable.control->accelerators, accel_path, closure);
 
   dt_accel_t *accel = _lookup_accel(accel_path);
-  if(!accel) return; // this happens when the path doesn't match any accel (typos, ...)
+  if(!accel) return NULL; // this happens when the path doesn't match any accel (typos, ...)
 
   accel->closure = closure;
 
   module->accel_closures = g_slist_prepend(module->accel_closures, accel);
+  return accel;
 }
 
 void dt_accel_connect_lua(const gchar *path, GClosure *closure)
@@ -323,16 +326,48 @@ static gboolean _press_button_callback(GtkAccelGroup *accel_group, GObject *acce
   return TRUE;
 }
 
+static gboolean _tooltip_callback(GtkWidget *widget, gint x, gint y, gboolean keyboard_mode,
+                                  GtkTooltip *tooltip, gpointer user_data)
+{
+  char *text = gtk_widget_get_tooltip_text(widget);
+
+  GtkAccelKey key;
+  dt_accel_t *accel = g_object_get_data(G_OBJECT(widget), "dt-accel");
+  if(accel && gtk_accel_map_lookup_entry(accel->path, &key))
+  {
+    gchar *key_name = gtk_accelerator_get_label(key.accel_key, key.accel_mods);
+    if(key_name && *key_name)
+    {
+      char *tmp = g_strdup_printf("%s (%s)", text, key_name);
+      g_free(text);
+      text = tmp;
+    }
+    g_free(key_name);
+  }
+
+  gtk_tooltip_set_text(tooltip, text);
+  g_free(text);
+  return TRUE;
+}
+
 void dt_accel_connect_button_iop(dt_iop_module_t *module, const gchar *path, GtkWidget *button)
 {
   GClosure *closure = g_cclosure_new(G_CALLBACK(_press_button_callback), button, NULL);
-  dt_accel_connect_iop(module, path, closure);
+  dt_accel_t *accel = dt_accel_connect_iop(module, path, closure);
+  g_object_set_data(G_OBJECT(button), "dt-accel", accel);
+
+  if(gtk_widget_get_has_tooltip(button))
+    g_signal_connect(G_OBJECT(button), "query-tooltip", G_CALLBACK(_tooltip_callback), NULL);
 }
 
 void dt_accel_connect_button_lib(dt_lib_module_t *module, const gchar *path, GtkWidget *button)
 {
   GClosure *closure = g_cclosure_new(G_CALLBACK(_press_button_callback), button, NULL);
-  dt_accel_connect_lib(module, path, closure);
+  dt_accel_t *accel = dt_accel_connect_lib(module, path, closure);
+  g_object_set_data(G_OBJECT(button), "dt-accel", accel);
+
+  if(gtk_widget_get_has_tooltip(button))
+    g_signal_connect(G_OBJECT(button), "query-tooltip", G_CALLBACK(_tooltip_callback), NULL);
 }
 
 static gboolean bauhaus_slider_edit_callback(GtkAccelGroup *accel_group, GObject *acceleratable, guint keyval,
@@ -498,11 +533,14 @@ void dt_accel_disconnect_locals_iop(dt_iop_module_t *module)
   while(l)
   {
     accel = (dt_accel_t *)l->data;
-    if(accel) gtk_accel_group_disconnect(darktable.control->accelerators, accel->closure);
-    l = g_slist_delete_link(l, l);
+    if(accel)
+    {
+      g_closure_ref(accel->closure);
+      gtk_accel_group_disconnect(darktable.control->accelerators, accel->closure);
+    }
+    l = g_slist_next(l);
   }
 
-  module->accel_closures_local = NULL;
   module->local_closures_connected = FALSE;
 }
 
@@ -545,9 +583,9 @@ static gboolean preset_iop_module_callback(GtkAccelGroup *accel_group, GObject *
   const char *name = callback_description->name;
 
   sqlite3_stmt *stmt;
-  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select op_params, enabled, blendop_params, "
-                                                             "blendop_version from presets where operation = "
-                                                             "?1 and name = ?2",
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "SELECT op_params, enabled, blendop_params, "
+                                                             "blendop_version FROM data.presets "
+                                                             "WHERE operation = ?1 AND name = ?2",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, module->op, -1, SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, name, -1, SQLITE_TRANSIENT);
@@ -631,7 +669,7 @@ static gboolean preset_lib_module_callback(GtkAccelGroup *accel_group, GObject *
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "select op_params from presets where operation = ?1 and op_version = ?2 and name = ?3", -1, &stmt,
+      "SELECT op_params FROM data.presets WHERE operation = ?1 AND op_version = ?2 AND name = ?3", -1, &stmt,
       NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, module->plugin_name, -1, SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 2, module->version());
@@ -662,7 +700,7 @@ static gboolean preset_lib_module_callback(GtkAccelGroup *accel_group, GObject *
   {
     dt_control_log(_("deleting preset for obsolete module"));
     DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                                "delete from presets where operation = ?1 and op_version = ?2 and name = ?3",
+                                "DELETE FROM data.presets WHERE operation = ?1 AND op_version = ?2 AND name = ?3",
                                 -1, &stmt, NULL);
     DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, module->plugin_name, -1, SQLITE_TRANSIENT);
     DT_DEBUG_SQLITE3_BIND_INT(stmt, 2, module->version());
@@ -742,7 +780,6 @@ void dt_accel_deregister_iop(dt_iop_module_t *module, const gchar *path)
 
 void dt_accel_deregister_lib(dt_lib_module_t *module, const gchar *path)
 {
-  dt_accel_t *accel;
   GSList *l;
   char build_path[1024];
   dt_accel_path_lib(build_path, sizeof(build_path), module->plugin_name, path);
@@ -764,7 +801,7 @@ void dt_accel_deregister_lib(dt_lib_module_t *module, const gchar *path)
   l = darktable.control->accelerator_list;
   while(l)
   {
-    accel = (dt_accel_t *)l->data;
+    dt_accel_t *accel = (dt_accel_t *)l->data;
     if(accel && !strncmp(accel->path, build_path, 1024))
     {
       darktable.control->accelerator_list = g_slist_delete_link(darktable.control->accelerator_list, l);
@@ -938,4 +975,4 @@ void dt_accel_rename_lua(const gchar *path, const gchar *new_path)
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
