@@ -19,16 +19,16 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+#include "bauhaus/bauhaus.h"
 #include "common/darktable.h"
 #include "common/debug.h"
-#include "bauhaus/bauhaus.h"
 #include "develop/blend.h"
 #include "develop/develop.h"
+#include "gui/accelerators.h"
 #include "gui/gtk.h"
 #include "gui/presets.h"
-#include "gui/accelerators.h"
-#include <stdlib.h>
 #include <assert.h>
+#include <stdlib.h>
 
 
 static const int dt_gui_presets_exposure_value_cnt = 24;
@@ -75,7 +75,7 @@ typedef struct dt_gui_presets_edit_dialog_t
 void dt_gui_presets_init()
 {
   // remove auto generated presets from plugins, not the user included ones.
-  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "DELETE FROM presets WHERE writeprotect = 1", NULL,
+  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "DELETE FROM data.presets WHERE writeprotect = 1", NULL,
                         NULL, NULL);
 }
 
@@ -99,7 +99,7 @@ void dt_gui_presets_add_generic(const char *name, dt_dev_operation_t op, const i
 
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "INSERT OR REPLACE INTO presets (name, description, operation, op_version, op_params, enabled, "
+      "INSERT OR REPLACE INTO data.presets (name, description, operation, op_version, op_params, enabled, "
       "blendop_params, blendop_version, multi_priority, multi_name, model, maker, lens, "
       "iso_min, iso_max, exposure_min, exposure_max, aperture_min, aperture_max, focal_length_min, "
       "focal_length_max, "
@@ -148,8 +148,8 @@ static gchar *get_active_preset_name(dt_iop_module_t *module)
 {
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                              "select name, op_params, blendop_params, enabled from presets where "
-                              "operation=?1 and op_version=?2 order by writeprotect desc, lower(name), rowid",
+                              "SELECT name, op_params, blendop_params, enabled FROM data.presets WHERE "
+                              "operation=?1 AND op_version=?2 ORDER BY writeprotect DESC, LOWER(name), rowid",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, module->op, -1, SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 2, module->version());
@@ -192,7 +192,7 @@ static void menuitem_delete_preset(GtkMenuItem *menuitem, dt_iop_module_t *modul
     dt_accel_deregister_iop(module, tmp_path);
     DT_DEBUG_SQLITE3_PREPARE_V2(
         dt_database_get(darktable.db),
-        "delete from presets where name=?1 and operation=?2 and op_version=?3 and writeprotect=0", -1, &stmt,
+        "DELETE FROM data.presets WHERE name=?1 AND operation=?2 AND op_version=?3 AND writeprotect=0", -1, &stmt,
         NULL);
     DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, name, -1, SQLITE_TRANSIENT);
     DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, module->op, -1, SQLITE_TRANSIENT);
@@ -235,7 +235,8 @@ static void edit_preset_response(GtkDialog *dialog, gint response_id, dt_gui_pre
       // name:
       DT_DEBUG_SQLITE3_PREPARE_V2(
           dt_database_get(darktable.db),
-          "select name from presets where name = ?1 and operation=?2 and op_version=?3", -1, &stmt, NULL);
+          "SELECT name FROM data.presets WHERE name = ?1 AND operation=?2 AND op_version=?3 LIMIT 1",
+          -1, &stmt, NULL);
       DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, name, -1, SQLITE_TRANSIENT);
       DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, g->module->op, -1, SQLITE_TRANSIENT);
       DT_DEBUG_SQLITE3_BIND_INT(stmt, 3, g->module->version());
@@ -269,7 +270,7 @@ static void edit_preset_response(GtkDialog *dialog, gint response_id, dt_gui_pre
     {
       // now delete old preset:
       DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                                  "delete from presets where name=?1 and operation=?2 and op_version=?3", -1,
+                                  "DELETE FROM data.presets WHERE name=?1 AND operation=?2 AND op_version=?3", -1,
                                   &stmt, NULL);
       DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, g->original_name, -1, SQLITE_TRANSIENT);
       DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, g->module->op, -1, SQLITE_TRANSIENT);
@@ -283,7 +284,7 @@ static void edit_preset_response(GtkDialog *dialog, gint response_id, dt_gui_pre
     {
       // delete preset, so we can re-insert the new values:
       DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                                  "delete from presets where name=?1 and operation=?2 and op_version=?3", -1,
+                                  "DELETE FROM data.presets WHERE name=?1 AND operation=?2 AND op_version=?3", -1,
                                   &stmt, NULL);
       DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, name, -1, SQLITE_TRANSIENT);
       DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, g->module->op, -1, SQLITE_TRANSIENT);
@@ -299,7 +300,7 @@ static void edit_preset_response(GtkDialog *dialog, gint response_id, dt_gui_pre
     // commit all the user input fields
     DT_DEBUG_SQLITE3_PREPARE_V2(
         dt_database_get(darktable.db),
-        "INSERT INTO presets (name, description, operation, op_version, op_params, enabled, "
+        "INSERT INTO data.presets (name, description, operation, op_version, op_params, enabled, "
         "blendop_params, blendop_version, multi_priority, multi_name, "
         "model, maker, lens, iso_min, iso_max, exposure_min, exposure_max, aperture_min, aperture_max, "
         "focal_length_min, focal_length_max, writeprotect, autoapply, filter, def, format) "
@@ -396,21 +397,19 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   g->name = GTK_ENTRY(gtk_entry_new());
   gtk_entry_set_text(g->name, name);
   gtk_box_pack_start(box, GTK_WIDGET(g->name), FALSE, FALSE, 0);
-  g_object_set(G_OBJECT(g->name), "tooltip-text", _("name of the preset"), (char *)NULL);
+  gtk_widget_set_tooltip_text(GTK_WIDGET(g->name), _("name of the preset"));
 
   g->description = GTK_ENTRY(gtk_entry_new());
   gtk_box_pack_start(box, GTK_WIDGET(g->description), FALSE, FALSE, 0);
-  g_object_set(G_OBJECT(g->description), "tooltip-text", _("description or further information"),
-               (char *)NULL);
+  gtk_widget_set_tooltip_text(GTK_WIDGET(g->description), _("description or further information"));
 
   g->autoapply
       = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("auto apply this preset to matching images")));
   gtk_box_pack_start(box, GTK_WIDGET(g->autoapply), FALSE, FALSE, 0);
   g->filter
       = GTK_CHECK_BUTTON(gtk_check_button_new_with_label(_("only show this preset for matching images")));
-  g_object_set(G_OBJECT(g->filter), "tooltip-text",
-               _("be very careful with this option. this might be the last time you see your preset."),
-               (char *)NULL);
+  gtk_widget_set_tooltip_text(GTK_WIDGET(g->filter), _("be very careful with this option. "
+                                                           "this might be the last time you see your preset."));
   gtk_box_pack_start(box, GTK_WIDGET(g->filter), FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(g->autoapply), "toggled", G_CALLBACK(check_buttons_activated), g);
   g_signal_connect(G_OBJECT(g->filter), "toggled", G_CALLBACK(check_buttons_activated), g);
@@ -424,23 +423,21 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   // model, maker, lens
   g->model = gtk_entry_new();
   gtk_widget_set_hexpand(GTK_WIDGET(g->model), TRUE);
-  g_object_set(G_OBJECT(g->model), "tooltip-text", _("string to match model (use % as wildcard)"),
-               (char *)NULL);
+  gtk_widget_set_tooltip_text(g->model, _("string to match model (use % as wildcard)"));
   label = gtk_label_new(_("model"));
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   gtk_grid_attach(GTK_GRID(g->details), label, 0, line++, 1, 1);
   gtk_grid_attach_next_to(GTK_GRID(g->details), g->model, label, GTK_POS_RIGHT, 2, 1);
 
   g->maker = gtk_entry_new();
-  g_object_set(G_OBJECT(g->maker), "tooltip-text", _("string to match maker (use % as wildcard)"),
-               (char *)NULL);
+  gtk_widget_set_tooltip_text(g->maker, _("string to match maker (use % as wildcard)"));
   label = gtk_label_new(_("maker"));
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   gtk_grid_attach(GTK_GRID(g->details), label, 0, line++, 1, 1);
   gtk_grid_attach_next_to(GTK_GRID(g->details), g->maker, label, GTK_POS_RIGHT, 2, 1);
 
   g->lens = gtk_entry_new();
-  g_object_set(G_OBJECT(g->lens), "tooltip-text", _("string to match lens (use % as wildcard)"), (char *)NULL);
+  gtk_widget_set_tooltip_text(g->lens, _("string to match lens (use % as wildcard)"));
   label = gtk_label_new(_("lens"));
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   gtk_grid_attach(GTK_GRID(g->details), label, 0, line++, 1, 1);
@@ -450,10 +447,10 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   label = gtk_label_new(_("ISO"));
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   g->iso_min = gtk_spin_button_new_with_range(0, 51200, 100);
-  g_object_set(G_OBJECT(g->iso_min), "tooltip-text", _("minimum ISO value"), (char *)NULL);
+  gtk_widget_set_tooltip_text(g->iso_min, _("minimum ISO value"));
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(g->iso_min), 0);
   g->iso_max = gtk_spin_button_new_with_range(0, 51200, 100);
-  g_object_set(G_OBJECT(g->iso_max), "tooltip-text", _("maximum ISO value"), (char *)NULL);
+  gtk_widget_set_tooltip_text(g->iso_max, _("maximum ISO value"));
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(g->iso_max), 0);
   gtk_grid_attach(GTK_GRID(g->details), label, 0, line++, 1, 1);
   gtk_grid_attach_next_to(GTK_GRID(g->details), g->iso_min, label, GTK_POS_RIGHT, 1, 1);
@@ -464,8 +461,8 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   g->exposure_min = dt_bauhaus_combobox_new(NULL);
   g->exposure_max = dt_bauhaus_combobox_new(NULL);
-  g_object_set(G_OBJECT(g->exposure_min), "tooltip-text", _("minimum exposure time"), (char *)NULL);
-  g_object_set(G_OBJECT(g->exposure_max), "tooltip-text", _("maximum exposure time"), (char *)NULL);
+  gtk_widget_set_tooltip_text(g->exposure_min, _("minimum exposure time"));
+  gtk_widget_set_tooltip_text(g->exposure_max, _("maximum exposure time"));
   for(int k = 0; k < dt_gui_presets_exposure_value_cnt; k++)
     dt_bauhaus_combobox_add(g->exposure_min, dt_gui_presets_exposure_value_str[k]);
   for(int k = 0; k < dt_gui_presets_exposure_value_cnt; k++)
@@ -479,8 +476,8 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   gtk_widget_set_halign(label, GTK_ALIGN_START);
   g->aperture_min = dt_bauhaus_combobox_new(NULL);
   g->aperture_max = dt_bauhaus_combobox_new(NULL);
-  g_object_set(G_OBJECT(g->aperture_min), "tooltip-text", _("minimum aperture value"), (char *)NULL);
-  g_object_set(G_OBJECT(g->aperture_max), "tooltip-text", _("maximum aperture value"), (char *)NULL);
+  gtk_widget_set_tooltip_text(g->aperture_min, _("minimum aperture value"));
+  gtk_widget_set_tooltip_text(g->aperture_max, _("maximum aperture value"));
   for(int k = 0; k < dt_gui_presets_aperture_value_cnt; k++)
     dt_bauhaus_combobox_add(g->aperture_min, dt_gui_presets_aperture_value_str[k]);
   for(int k = 0; k < dt_gui_presets_aperture_value_cnt; k++)
@@ -496,8 +493,8 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(g->focal_length_min), 0);
   g->focal_length_max = gtk_spin_button_new_with_range(0, 1000, 10);
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(g->focal_length_max), 0);
-  g_object_set(G_OBJECT(g->focal_length_min), "tooltip-text", _("minimum focal length"), (char *)NULL);
-  g_object_set(G_OBJECT(g->focal_length_max), "tooltip-text", _("maximum focal length"), (char *)NULL);
+  gtk_widget_set_tooltip_text(g->focal_length_min, _("minimum focal length"));
+  gtk_widget_set_tooltip_text(g->focal_length_max, _("maximum focal length"));
   gtk_grid_attach(GTK_GRID(g->details), label, 0, line++, 1, 1);
   gtk_grid_attach_next_to(GTK_GRID(g->details), g->focal_length_min, label, GTK_POS_RIGHT, 1, 1);
   gtk_grid_attach_next_to(GTK_GRID(g->details), g->focal_length_max, g->focal_length_min, GTK_POS_RIGHT, 1, 1);
@@ -519,7 +516,7 @@ static void edit_preset(const char *name_in, dt_iop_module_t *module)
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
                               "SELECT rowid, description, model, maker, lens, iso_min, iso_max, "
                               "exposure_min, exposure_max, aperture_min, aperture_max, focal_length_min, "
-                              "focal_length_max, autoapply, filter, format FROM presets WHERE name = ?1 AND "
+                              "focal_length_max, autoapply, filter, format FROM data.presets WHERE name = ?1 AND "
                               "operation = ?2 AND op_version = ?3",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, name, -1, SQLITE_TRANSIENT);
@@ -610,7 +607,7 @@ static void menuitem_update_preset(GtkMenuItem *menuitem, dt_iop_module_t *modul
   // commit all the module fields
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                              "UPDATE presets SET op_version=?2, op_params=?3, enabled=?4, "
+                              "UPDATE data.presets SET op_version=?2, op_params=?3, enabled=?4, "
                               "blendop_params=?5, blendop_version=?6 WHERE name=?7 AND operation=?1",
                               -1, &stmt, NULL);
 
@@ -631,7 +628,7 @@ static void menuitem_new_preset(GtkMenuItem *menuitem, dt_iop_module_t *module)
   // add new preset
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                              "delete from presets where name=?1 and operation=?2 and op_version=?3", -1,
+                              "DELETE FROM data.presets WHERE name=?1 AND operation=?2 AND op_version=?3", -1,
                               &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, _("new preset"), -1, SQLITE_STATIC);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, module->op, -1, SQLITE_TRANSIENT);
@@ -652,8 +649,8 @@ static void menuitem_pick_preset(GtkMenuItem *menuitem, dt_iop_module_t *module)
   gchar *name = get_preset_name(menuitem);
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                              "select op_params, enabled, blendop_params, blendop_version, writeprotect from "
-                              "presets where operation = ?1 and op_version = ?2 and name = ?3",
+                              "SELECT op_params, enabled, blendop_params, blendop_version, writeprotect FROM "
+                              "data.presets WHERE operation = ?1 AND op_version = ?2 AND name = ?3",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, module->op, -1, SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 2, module->version());
@@ -723,10 +720,10 @@ void dt_gui_favorite_presets_menu_show()
         gtk_menu_item_set_submenu(smi, GTK_WIDGET(sm));
 
         /* query presets for module */
-        DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select name, op_params, writeprotect, "
+        DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "SELECT name, op_params, writeprotect, "
                                                                    "description, blendop_params, op_version "
-                                                                   "from presets where operation=?1 order by "
-                                                                   "writeprotect desc, lower(name), rowid",
+                                                                   "FROM data.presets WHERE operation=?1 ORDER BY "
+                                                                   "writeprotect DESC, LOWER(name), rowid",
                                     -1, &stmt, NULL);
         DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, iop->op, -1, SQLITE_TRANSIENT);
 
@@ -780,18 +777,18 @@ static void dt_gui_presets_popup_menu_show_internal(dt_dev_operation_t op, int32
   {
     // only matching if filter is on:
     DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                                "select name, op_params, writeprotect, description, blendop_params, "
-                                "op_version, enabled from presets where operation=?1 and "
-                                "(filter=0 or ( "
-                                "((?2 like model and ?3 like maker) or (?4 like model and ?5 like maker)) and "
-                                "?6 like lens and "
-                                "?7 between iso_min and iso_max and "
-                                "?8 between exposure_min and exposure_max and "
-                                "?9 between aperture_min and aperture_max and "
-                                "?10 between focal_length_min and focal_length_max and "
-                                "(format = 0 or format&?9!=0)"
+                                "SELECT name, op_params, writeprotect, description, blendop_params, "
+                                "op_version, enabled FROM data.presets WHERE operation=?1 AND "
+                                "(filter=0 OR ( "
+                                "((?2 LIKE model AND ?3 LIKE maker) OR (?4 LIKE model AND ?5 LIKE maker)) AND "
+                                "?6 LIKE lens AND "
+                                "?7 BETWEEN iso_min AND iso_max AND "
+                                "?8 BETWEEN exposure_min AND exposure_max AND "
+                                "?9 BETWEEN aperture_min AND aperture_max AND "
+                                "?10 BETWEEN focal_length_min AND focal_length_max AND "
+                                "(format = 0 OR format&?11!=0)"
                                 " ) )"
-                                "order by writeprotect desc, lower(name), rowid",
+                                "ORDER BY writeprotect DESC, LOWER(name), rowid",
                                 -1, &stmt, NULL);
     DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, op, -1, SQLITE_TRANSIENT);
     DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, image->exif_model, -1, SQLITE_TRANSIENT);
@@ -804,15 +801,15 @@ static void dt_gui_presets_popup_menu_show_internal(dt_dev_operation_t op, int32
     DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 9, image->exif_aperture);
     DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 10, image->exif_focal_length);
     int ldr = dt_image_is_ldr(image) ? FOR_LDR : (dt_image_is_raw(image) ? FOR_RAW : FOR_HDR);
-    DT_DEBUG_SQLITE3_BIND_INT(stmt, 9, ldr);
+    DT_DEBUG_SQLITE3_BIND_INT(stmt, 11, ldr);
   }
   else
   {
     // don't know for which image. show all we got:
-    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select name, op_params, writeprotect, "
+    DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "SELECT name, op_params, writeprotect, "
                                                                "description, blendop_params, op_version, "
-                                                               "enabled from presets where operation=?1 "
-                                                               "order by writeprotect desc, lower(name), rowid",
+                                                               "enabled FROM data.presets WHERE operation=?1 "
+                                                               "ORDER BY writeprotect DESC, LOWER(name), rowid",
                                 -1, &stmt, NULL);
     DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, op, -1, SQLITE_TRANSIENT);
   }
@@ -870,7 +867,7 @@ static void dt_gui_presets_popup_menu_show_internal(dt_dev_operation_t op, int32
     if(isdisabled)
     {
       gtk_widget_set_sensitive(mi, 0);
-      g_object_set(G_OBJECT(mi), "tooltip-text", _("disabled: wrong module version"), (char *)NULL);
+      gtk_widget_set_tooltip_text(mi, _("disabled: wrong module version"));
     }
     else
     {
@@ -878,7 +875,7 @@ static void dt_gui_presets_popup_menu_show_internal(dt_dev_operation_t op, int32
         g_signal_connect(G_OBJECT(mi), "activate", G_CALLBACK(menuitem_pick_preset), module);
       else if(pick_callback)
         g_signal_connect(G_OBJECT(mi), "activate", G_CALLBACK(pick_callback), callback_data);
-      g_object_set(G_OBJECT(mi), "tooltip-text", sqlite3_column_text(stmt, 3), (char *)NULL);
+      gtk_widget_set_tooltip_text(mi, (const char *)sqlite3_column_text(stmt, 3));
     }
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), mi);
     cnt++;
@@ -943,7 +940,7 @@ void dt_gui_presets_update_mml(const char *name, dt_dev_operation_t op, const in
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "update presets set maker=?1, model=?2, lens=?3 where operation=?4 and op_version=?5 and name=?6", -1,
+      "UPDATE data.presets SET maker=?1, model=?2, lens=?3 WHERE operation=?4 AND op_version=?5 AND name=?6", -1,
       &stmt, NULL);
   snprintf(tmp, sizeof(tmp), "%%%s%%", maker);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 1, tmp, -1, SQLITE_TRANSIENT);
@@ -964,7 +961,7 @@ void dt_gui_presets_update_iso(const char *name, dt_dev_operation_t op, const in
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "update presets set iso_min=?1, iso_max=?2 where operation=?3 and op_version=?4 and name=?5", -1, &stmt,
+      "UPDATE data.presets SET iso_min=?1, iso_max=?2 WHERE operation=?3 AND op_version=?4 AND name=?5", -1, &stmt,
       NULL);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 1, min);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 2, max);
@@ -981,7 +978,7 @@ void dt_gui_presets_update_av(const char *name, dt_dev_operation_t op, const int
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "update presets set aperture_min=?1, aperture_max=?2 where operation=?3 and op_version=?4 and name=?5",
+      "UPDATE data.presets SET aperture_min=?1, aperture_max=?2 WHERE operation=?3 AND op_version=?4 AND name=?5",
       -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 1, min);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 2, max);
@@ -998,7 +995,7 @@ void dt_gui_presets_update_tv(const char *name, dt_dev_operation_t op, const int
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "update presets set exposure_min=?1, exposure_max=?2 where operation=?3 and op_version=?4 and name=?5",
+      "UPDATE data.presets SET exposure_min=?1, exposure_max=?2 WHERE operation=?3 AND op_version=?4 AND name=?5",
       -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 1, min);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 2, max);
@@ -1013,9 +1010,9 @@ void dt_gui_presets_update_fl(const char *name, dt_dev_operation_t op, const int
                               const float max)
 {
   sqlite3_stmt *stmt;
-  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "update presets set focal_length_min=?1, "
-                                                             "focal_length_max=?2 where operation=?3 and "
-                                                             "op_version=?4 and name=?5",
+  DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "UPDATE data.presets SET focal_length_min=?1, "
+                                                             "focal_length_max=?2 WHERE operation=?3 AND "
+                                                             "op_version=?4 AND name=?5",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 1, min);
   DT_DEBUG_SQLITE3_BIND_DOUBLE(stmt, 2, max);
@@ -1031,7 +1028,7 @@ void dt_gui_presets_update_ldr(const char *name, dt_dev_operation_t op, const in
 {
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                              "update presets set format=?1 where operation=?2 and op_version=?3 and name=?4",
+                              "UPDATE data.presets SET format=?1 WHERE operation=?2 AND op_version=?3 AND name=?4",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, ldrflag);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, op, -1, SQLITE_TRANSIENT);
@@ -1047,7 +1044,7 @@ void dt_gui_presets_update_autoapply(const char *name, dt_dev_operation_t op, co
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "update presets set autoapply=?1 where operation=?2 and op_version=?3 and name=?4", -1, &stmt, NULL);
+      "UPDATE data.presets SET autoapply=?1 WHERE operation=?2 AND op_version=?3 AND name=?4", -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, autoapply);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, op, -1, SQLITE_TRANSIENT);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 3, version);
@@ -1061,7 +1058,7 @@ void dt_gui_presets_update_filter(const char *name, dt_dev_operation_t op, const
 {
   sqlite3_stmt *stmt;
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db),
-                              "update presets set filter=?1 where operation=?2 and op_version=?3 and name=?4",
+                              "UPDATE data.presets SET filter=?1 WHERE operation=?2 AND op_version=?3 AND name=?4",
                               -1, &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, filter);
   DT_DEBUG_SQLITE3_BIND_TEXT(stmt, 2, op, -1, SQLITE_TRANSIENT);
@@ -1073,4 +1070,4 @@ void dt_gui_presets_update_filter(const char *name, dt_dev_operation_t op, const
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
