@@ -16,15 +16,15 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include <glib/gstdio.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <inttypes.h>
 #include "common/darktable.h"
-#include "common/imageio_module.h"
-#include "common/exif.h"
 #include "common/debug.h"
-#include "common/imageio_format.h"
+#include "common/exif.h"
+#include "common/imageio_module.h"
+#include "imageio/format/imageio_format_api.h"
+#include <glib/gstdio.h>
+#include <inttypes.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 DT_MODULE(1)
 
@@ -43,7 +43,7 @@ int write_image(dt_imageio_module_data_t *ppm, const char *filename, const void
 
   DT_DEBUG_SQLITE3_PREPARE_V2(
       dt_database_get(darktable.db),
-      "select folder, filename from images, film_rolls where images.id = ?1 and film_id = film_rolls.id;", -1,
+      "SELECT folder, filename FROM main.images i, main.film_rolls f ON i.film_id = f.id WHERE i.id = ?1", -1,
       &stmt, NULL);
   DT_DEBUG_SQLITE3_BIND_INT(stmt, 1, imgid);
 
@@ -160,4 +160,4 @@ void gui_reset(dt_imageio_module_format_t *self)
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
