@@ -15,23 +15,26 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include "develop/imageop.h"
-#include "develop/tiling.h"
-#include "common/opencl.h"
+#include "bauhaus/bauhaus.h"
 #include "common/debug.h"
+#include "common/opencl.h"
 #include "control/conf.h"
+#include "control/control.h"
+#include "develop/imageop.h"
+#include "develop/imageop_math.h"
+#include "develop/tiling.h"
+#include "dtgtk/drawingarea.h"
 #include "gui/accelerators.h"
 #include "gui/draw.h"
-#include "gui/presets.h"
-#include "dtgtk/drawingarea.h"
 #include "gui/gtk.h"
-#include "bauhaus/bauhaus.h"
-#include "control/control.h"
+#include "gui/presets.h"
+#include "iop/iop_api.h"
+
 #include <memory.h>
 #include <stdlib.h>
+#if defined(__SSE__)
 #include <xmmintrin.h>
-// SSE4 actually not used yet.
-// #include <smmintrin.h>
+#endif
 
 #define INSET DT_PIXEL_APPLY_DPI(5)
 #define INFL .3f
@@ -43,16 +46,18 @@ DT_MODULE_INTROSPECTION(1, dt_iop_atrous_params_t)
 #define MAX_NUM_SCALES 8 // 2*2^(i+1) + 1 = 1025px support for i = 8
 #define RES 64
 
-#define dt_atrous_show_upper_label(cr, text, ext)                                                            \
-  cairo_text_extents(cr, text, &ext);                                                                        \
-  cairo_move_to(cr, .5 * (width - ext.width), .08 * height);                                                 \
-  cairo_show_text(cr, text);
+#define dt_atrous_show_upper_label(cr, text, layout, ink)                                                     \
+  pango_layout_set_text(layout, text, -1);                                                                   \
+  pango_layout_get_pixel_extents(layout, &ink, NULL);                                                        \
+  cairo_move_to(cr, .5 * (width - ink.width), (.08 * height) - ink.height);                                  \
+  pango_cairo_show_layout(cr, layout);
 
 
-#define dt_atrous_show_lower_label(cr, text, ext)                                                            \
-  cairo_text_extents(cr, text, &ext);                                                                        \
-  cairo_move_to(cr, .5 * (width - ext.width), .98 * height);                                                 \
-  cairo_show_text(cr, text);
+#define dt_atrous_show_lower_label(cr, text, layout, ink)                                                     \
+  pango_layout_set_text(layout, text, -1);                                                                   \
+  pango_layout_get_pixel_extents(layout, &ink, NULL);                                                        \
+  cairo_move_to(cr, .5 * (width - ink.width), (.98 * height) - ink.height);                                  \
+  pango_cairo_show_layout(cr, layout);
 
 
 typedef enum atrous_channel_t
@@ -137,12 +142,13 @@ void connect_key_accels(dt_iop_module_t *self)
     (a), (a), (a), (a)                                                                                       \
   }
 
+#if defined(__SSE2__)
 static const __m128 fone ALIGNED(16) = VEC4(0x3f800000u);
 static const __m128 femo ALIGNED(16) = VEC4(0x00adf880u);
 static const __m128 ooo1 ALIGNED(16) = { 0.f, 0.f, 0.f, 1.f };
 
 /* SSE intrinsics version of dt_fast_expf defined in darktable.h */
-static inline __m128 dt_fast_expf_sse(const __m128 x)
+static inline __m128 dt_fast_expf_sse2(const __m128 x)
 {
   __m128 f = _mm_add_ps(fone, _mm_mul_ps(x, femo)); // f(n) = i1 + x(n)*(i2-i1)
   __m128i i = _mm_cvtps_epi32(f);                   // i(n) = int(f(n))
@@ -150,7 +156,25 @@ static inline __m128 dt_fast_expf_sse(const __m128 x)
   i = _mm_andnot_si128(mask, i);                    // i(n) = 0 if i(n) < 0
   return _mm_castsi128_ps(i);                       // return *(float*)&i
 }
+#endif
 
+static inline void weight(const float *c1, const float *c2, const float sharpen, float *weight)
+{
+  float diff[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
+  for(int c = 0; c < 4; c++) diff[c] = c1[c] - c2[c];
+  float square[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
+  for(int c = 0; c < 4; c++) square[c] = diff[c] * diff[c];
+
+  const float wl = dt_fast_expf(-sharpen * square[0]);
+  const float wc = dt_fast_expf(-sharpen * (square[1] + square[2]));
+
+  weight[0] = wl;
+  weight[1] = wc;
+  weight[2] = wc;
+  weight[3] = 1.0f;
+}
+
+#if defined(__SSE2__)
 /* Computes the vector
  * (wl, wc, wc, 1)
  *
@@ -160,7 +184,7 @@ static inline __m128 dt_fast_expf_sse(const __m128 x)
  * wc = exp(-sharpen*(SQR(c1[1] - c2[1]) + SQR(c1[2] - c2[2]))
  *    = exp(-s*(d2+d3)) (as noted in code comments below)
  */
-static inline __m128 weight_sse(const __m128 *c1, const __m128 *c2, const float sharpen)
+static inline __m128 weight_sse2(const __m128 *c1, const __m128 *c2, const float sharpen)
 {
   const __m128 vsharpen = _mm_set1_ps(-sharpen); // (-s, -s, -s, -s)
   __m128 diff = _mm_sub_ps(*c1, *c2);
@@ -169,23 +193,40 @@ static inline __m128 weight_sse(const __m128 *c1, const __m128 *c2, const float
   __m128 added = _mm_add_ps(square, square2);                               // (?, d2+d3, d2+d3, 2*d1)
   added = _mm_sub_ss(added, square);                                        // (?, d2+d3, d2+d3, d1)
   __m128 sharpened = _mm_mul_ps(added, vsharpen);                   // (?, -s*(d2+d3), -s*(d2+d3), -s*d1)
-  __m128 exp = dt_fast_expf_sse(sharpened);                         // (?, wc, wc, wl)
+  __m128 exp = dt_fast_expf_sse2(sharpened);                        // (?, wc, wc, wl)
   exp = _mm_castsi128_ps(_mm_slli_si128(_mm_castps_si128(exp), 4)); // (wc, wc, wl, 0)
   exp = _mm_castsi128_ps(_mm_srli_si128(_mm_castps_si128(exp), 4)); // (0, wc, wc, wl)
   exp = _mm_or_ps(exp, ooo1);                                       // (1, wc, wc, wl)
   return exp;
 }
+#endif
 
 #define SUM_PIXEL_CONTRIBUTION_COMMON(ii, jj)                                                                \
+  do                                                                                                         \
+  {                                                                                                          \
+    const float f = filter[(ii)] * filter[(jj)];                                                             \
+    float wp[4] = { 0.0f, 0.0f, 0.0f, 0.0f };                                                                \
+    weight(px, px2, sharpen, wp);                                                                            \
+    float w[4] = { 0.0f, 0.0f, 0.0f, 0.0f };                                                                 \
+    for(int c = 0; c < 4; c++) w[c] = f * wp[c];                                                             \
+    float pd[4] = { 0.0f, 0.0f, 0.0f, 0.0f };                                                                \
+    for(int c = 0; c < 4; c++) pd[c] = w[c] * px2[c];                                                        \
+    for(int c = 0; c < 4; c++) sum[c] += pd[c];                                                              \
+    for(int c = 0; c < 4; c++) wgt[c] += w[c];                                                               \
+  } while(0)
+
+#if defined(__SSE2__)
+#define SUM_PIXEL_CONTRIBUTION_COMMON_SSE2(ii, jj)                                                           \
   do                                                                                                         \
   {                                                                                                          \
     const __m128 f = _mm_set1_ps(filter[(ii)] * filter[(jj)]);                                               \
-    const __m128 wp = weight_sse(px, px2, sharpen);                                                          \
+    const __m128 wp = weight_sse2(px, px2, sharpen);                                                         \
     const __m128 w = _mm_mul_ps(f, wp);                                                                      \
     const __m128 pd = _mm_mul_ps(w, *px2);                                                                   \
     sum = _mm_add_ps(sum, pd);                                                                               \
     wgt = _mm_add_ps(wgt, w);                                                                                \
   } while(0)
+#endif
 
 #define SUM_PIXEL_CONTRIBUTION_WITH_TEST(ii, jj)                                                             \
   do                                                                                                         \
@@ -200,22 +241,66 @@ static inline __m128 weight_sse(const __m128 *c1, const __m128 *c2, const float
     if(y < 0) y = 0;                                                                                         \
     if(y >= height) y = height - 1;                                                                          \
                                                                                                              \
-    px2 = ((__m128 *)in) + x + (size_t)y * width;                                                            \
+    px2 = ((float *)in) + 4 * x + (size_t)4 * y * width;                                                     \
                                                                                                              \
     SUM_PIXEL_CONTRIBUTION_COMMON(ii, jj);                                                                   \
   } while(0)
 
+#if defined(__SSE2__)
+#define SUM_PIXEL_CONTRIBUTION_WITH_TEST_SSE2(ii, jj)                                                        \
+  do                                                                                                         \
+  {                                                                                                          \
+    const int iii = (ii)-2;                                                                                  \
+    const int jjj = (jj)-2;                                                                                  \
+    int x = i + mult * iii;                                                                                  \
+    int y = j + mult * jjj;                                                                                  \
+                                                                                                             \
+    if(x < 0) x = 0;                                                                                         \
+    if(x >= width) x = width - 1;                                                                            \
+    if(y < 0) y = 0;                                                                                         \
+    if(y >= height) y = height - 1;                                                                          \
+                                                                                                             \
+    px2 = ((__m128 *)in) + x + (size_t)y * width;                                                            \
+                                                                                                             \
+    SUM_PIXEL_CONTRIBUTION_COMMON_SSE2(ii, jj);                                                              \
+  } while(0)
+#endif
+
 #define ROW_PROLOGUE                                                                                         \
+  const float *px = ((float *)in) + (size_t)4 * j * width;                                                   \
+  const float *px2;                                                                                          \
+  float *pdetail = detail + (size_t)4 * j * width;                                                           \
+  float *pcoarse = out + (size_t)4 * j * width;
+
+#if defined(__SSE2__)
+#define ROW_PROLOGUE_SSE                                                                                     \
   const __m128 *px = ((__m128 *)in) + (size_t)j * width;                                                     \
   const __m128 *px2;                                                                                         \
   float *pdetail = detail + (size_t)4 * j * width;                                                           \
   float *pcoarse = out + (size_t)4 * j * width;
+#endif
 
 #define SUM_PIXEL_PROLOGUE                                                                                   \
+  float sum[4] = { 0.0f, 0.0f, 0.0f, 0.0f };                                                                 \
+  float wgt[4] = { 0.0f, 0.0f, 0.0f, 0.0f };
+
+#if defined(__SSE2__)
+#define SUM_PIXEL_PROLOGUE_SSE                                                                               \
   __m128 sum = _mm_setzero_ps();                                                                             \
   __m128 wgt = _mm_setzero_ps();
+#endif
 
 #define SUM_PIXEL_EPILOGUE                                                                                   \
+  for(int c = 0; c < 4; c++) sum[c] /= wgt[c];                                                               \
+                                                                                                             \
+  for(int c = 0; c < 4; c++) pdetail[c] = (px[c] - sum[c]);                                                  \
+  for(int c = 0; c < 4; c++) pcoarse[c] = sum[c];                                                            \
+  px += 4;                                                                                                   \
+  pdetail += 4;                                                                                              \
+  pcoarse += 4;
+
+#if defined(__SSE2__)
+#define SUM_PIXEL_EPILOGUE_SSE                                                                               \
   sum = _mm_mul_ps(sum, _mm_rcp_ps(wgt));                                                                    \
                                                                                                              \
   _mm_stream_ps(pdetail, _mm_sub_ps(*px, sum));                                                              \
@@ -223,6 +308,10 @@ static inline __m128 weight_sse(const __m128 *c1, const __m128 *c2, const float
   px++;                                                                                                      \
   pdetail += 4;                                                                                              \
   pcoarse += 4;
+#endif
+
+typedef void((*eaw_decompose_t)(float *const out, const float *const in, float *const detail, const int scale,
+                                const float sharpen, const int32_t width, const int32_t height));
 
 static void eaw_decompose(float *const out, const float *const in, float *const detail, const int scale,
                           const float sharpen, const int32_t width, const int32_t height)
@@ -280,15 +369,15 @@ static void eaw_decompose(float *const out, const float *const in, float *const
     for(int i = 2 * mult; i < width - 2 * mult; i++)
     {
       SUM_PIXEL_PROLOGUE
-      px2 = ((__m128 *)in) + i - 2 * mult + (size_t)(j - 2 * mult) * width;
+      px2 = ((float *)in) + (size_t)4 * (i - 2 * mult + (size_t)(j - 2 * mult) * width);
       for(int jj = 0; jj < 5; jj++)
       {
         for(int ii = 0; ii < 5; ii++)
         {
           SUM_PIXEL_CONTRIBUTION_COMMON(ii, jj);
-          px2 += mult;
+          px2 += (size_t)4 * mult;
         }
-        px2 += (width - 5) * mult;
+        px2 += (size_t)4 * (width - 5) * mult;
       }
       SUM_PIXEL_EPILOGUE
     }
@@ -330,8 +419,6 @@ static void eaw_decompose(float *const out, const float *const in, float *const
       SUM_PIXEL_EPILOGUE
     }
   }
-
-  _mm_sfence();
 }
 
 #undef SUM_PIXEL_CONTRIBUTION_COMMON
@@ -340,8 +427,152 @@ static void eaw_decompose(float *const out, const float *const in, float *const
 #undef SUM_PIXEL_PROLOGUE
 #undef SUM_PIXEL_EPILOGUE
 
+#if defined(__SSE2__)
+static void eaw_decompose_sse2(float *const out, const float *const in, float *const detail, const int scale,
+                               const float sharpen, const int32_t width, const int32_t height)
+{
+  const int mult = 1 << scale;
+  static const float filter[5] = { 1.0f / 16.0f, 4.0f / 16.0f, 6.0f / 16.0f, 4.0f / 16.0f, 1.0f / 16.0f };
+
+/* The first "2*mult" lines use the macro with tests because the 5x5 kernel
+ * requires nearest pixel interpolation for at least a pixel in the sum */
+#ifdef _OPENMP
+#pragma omp parallel for default(none) schedule(static)
+#endif
+  for(int j = 0; j < 2 * mult; j++)
+  {
+    ROW_PROLOGUE_SSE
+
+    for(int i = 0; i < width; i++)
+    {
+      SUM_PIXEL_PROLOGUE_SSE
+      for(int jj = 0; jj < 5; jj++)
+      {
+        for(int ii = 0; ii < 5; ii++)
+        {
+          SUM_PIXEL_CONTRIBUTION_WITH_TEST_SSE2(ii, jj);
+        }
+      }
+      SUM_PIXEL_EPILOGUE_SSE
+    }
+  }
+
+#ifdef _OPENMP
+#pragma omp parallel for default(none) schedule(static)
+#endif
+  for(int j = 2 * mult; j < height - 2 * mult; j++)
+  {
+    ROW_PROLOGUE_SSE
+
+    /* The first "2*mult" pixels use the macro with tests because the 5x5 kernel
+     * requires nearest pixel interpolation for at least a pixel in the sum */
+    for(int i = 0; i < 2 * mult; i++)
+    {
+      SUM_PIXEL_PROLOGUE_SSE
+      for(int jj = 0; jj < 5; jj++)
+      {
+        for(int ii = 0; ii < 5; ii++)
+        {
+          SUM_PIXEL_CONTRIBUTION_WITH_TEST_SSE2(ii, jj);
+        }
+      }
+      SUM_PIXEL_EPILOGUE_SSE
+    }
+
+    /* For pixels [2*mult, width-2*mult], we can safely use macro w/o tests
+     * to avoid unneeded branching in the inner loops */
+    for(int i = 2 * mult; i < width - 2 * mult; i++)
+    {
+      SUM_PIXEL_PROLOGUE_SSE
+      px2 = ((__m128 *)in) + i - 2 * mult + (size_t)(j - 2 * mult) * width;
+      for(int jj = 0; jj < 5; jj++)
+      {
+        for(int ii = 0; ii < 5; ii++)
+        {
+          SUM_PIXEL_CONTRIBUTION_COMMON_SSE2(ii, jj);
+          px2 += mult;
+        }
+        px2 += (width - 5) * mult;
+      }
+      SUM_PIXEL_EPILOGUE_SSE
+    }
+
+    /* Last two pixels in the row require a slow variant... blablabla */
+    for(int i = width - 2 * mult; i < width; i++)
+    {
+      SUM_PIXEL_PROLOGUE_SSE
+      for(int jj = 0; jj < 5; jj++)
+      {
+        for(int ii = 0; ii < 5; ii++)
+        {
+          SUM_PIXEL_CONTRIBUTION_WITH_TEST_SSE2(ii, jj);
+        }
+      }
+      SUM_PIXEL_EPILOGUE_SSE
+    }
+  }
+
+/* The last "2*mult" lines use the macro with tests because the 5x5 kernel
+ * requires nearest pixel interpolation for at least a pixel in the sum */
+#ifdef _OPENMP
+#pragma omp parallel for default(none) schedule(static)
+#endif
+  for(int j = height - 2 * mult; j < height; j++)
+  {
+    ROW_PROLOGUE_SSE
+
+    for(int i = 0; i < width; i++)
+    {
+      SUM_PIXEL_PROLOGUE_SSE
+      for(int jj = 0; jj < 5; jj++)
+      {
+        for(int ii = 0; ii < 5; ii++)
+        {
+          SUM_PIXEL_CONTRIBUTION_WITH_TEST_SSE2(ii, jj);
+        }
+      }
+      SUM_PIXEL_EPILOGUE_SSE
+    }
+  }
+
+  _mm_sfence();
+}
+
+#undef SUM_PIXEL_CONTRIBUTION_COMMON_SSE2
+#undef SUM_PIXEL_CONTRIBUTION_WITH_TEST_SSE2
+#undef ROW_PROLOGUE_SSE
+#undef SUM_PIXEL_PROLOGUE_SSE
+#undef SUM_PIXEL_EPILOGUE_SSE
+#endif
+
+typedef void((*eaw_synthesize_t)(float *const out, const float *const in, const float *const detail,
+                                 const float *thrsf, const float *boostf, const int32_t width,
+                                 const int32_t height));
+
 static void eaw_synthesize(float *const out, const float *const in, const float *const detail,
                            const float *thrsf, const float *boostf, const int32_t width, const int32_t height)
+{
+  const float threshold[4] = { thrsf[0], thrsf[1], thrsf[2], thrsf[3] };
+  const float boost[4] = { boostf[0], boostf[1], boostf[2], boostf[3] };
+
+#ifdef _OPENMP
+#pragma omp parallel for SIMD() default(none) schedule(static) collapse(2)
+#endif
+  for(size_t k = 0; k < (size_t)4 * width * height; k += 4)
+  {
+    for(size_t c = 0; c < 4; c++)
+    {
+      const float absamt = MAX(0.0f, (fabsf(detail[k + c]) - threshold[c]));
+      const float amount = copysignf(absamt, detail[k + c]);
+      out[k + c] = in[k + c] + (boost[c] * amount);
+    }
+  }
+}
+
+#if defined(__SSE2__)
+static void eaw_synthesize_sse2(float *const out, const float *const in, const float *const detail,
+                                const float *thrsf, const float *boostf, const int32_t width,
+                                const int32_t height)
 {
   const __m128 threshold = _mm_set_ps(thrsf[3], thrsf[2], thrsf[1], thrsf[0]);
   const __m128 boost = _mm_set_ps(boostf[3], boostf[2], boostf[1], boostf[0]);
@@ -370,6 +601,7 @@ static void eaw_synthesize(float *const out, const float *const in, const float
   }
   _mm_sfence();
 }
+#endif
 
 static int get_samples(float *t, const dt_iop_atrous_data_t *const d, const dt_iop_roi_t *roi_in,
                        const dt_dev_pixelpipe_iop_t *const piece)
@@ -437,8 +669,10 @@ static int get_scales(float (*thrs)[4], float (*boost)[4], float *sharp, const d
 }
 
 /* just process the supplied image buffer, upstream default_process_tiling() does the rest */
-void process(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, void *i, void *o,
-             const dt_iop_roi_t *roi_in, const dt_iop_roi_t *roi_out)
+static void process_wavelets(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece,
+                             const void *const i, void *const o, const dt_iop_roi_t *const roi_in,
+                             const dt_iop_roi_t *const roi_out, const eaw_decompose_t decompose,
+                             const eaw_synthesize_t synthesize)
 {
   dt_iop_atrous_data_t *d = (dt_iop_atrous_data_t *)piece->data;
   float thrs[MAX_NUM_SCALES][4];
@@ -484,7 +718,7 @@ void process(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece,
 
   for(int scale = 0; scale < max_scale; scale++)
   {
-    eaw_decompose(buf2, buf1, detail[scale], scale, sharp[scale], width, height);
+    decompose(buf2, buf1, detail[scale], scale, sharp[scale], width, height);
     if(scale == 0) buf1 = (float *)o; // now switch to (float *)o for buffer ping-pong between buf1 and buf2
     float *buf3 = buf2;
     buf2 = buf1;
@@ -493,7 +727,7 @@ void process(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece,
 
   for(int scale = max_scale - 1; scale >= 0; scale--)
   {
-    eaw_synthesize(buf2, buf1, detail[scale], thrs[scale], boost[scale], width, height);
+    synthesize(buf2, buf1, detail[scale], thrs[scale], boost[scale], width, height);
     float *buf3 = buf2;
     buf2 = buf1;
     buf1 = buf3;
@@ -514,10 +748,24 @@ error:
   return;
 }
 
+void process(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, const void *const i,
+             void *const o, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
+{
+  process_wavelets(self, piece, i, o, roi_in, roi_out, eaw_decompose, eaw_synthesize);
+}
+
+#if defined(__SSE2__)
+void process_sse2(struct dt_iop_module_t *self, struct dt_dev_pixelpipe_iop_t *piece, const void *const i,
+                  void *const o, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
+{
+  process_wavelets(self, piece, i, o, roi_in, roi_out, eaw_decompose_sse2, eaw_synthesize_sse2);
+}
+#endif
+
 #ifdef HAVE_OPENCL
 /* this version is adapted to the new global tiling mechanism. it no longer does tiling by itself. */
 int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_mem dev_in, cl_mem dev_out,
-               const dt_iop_roi_t *roi_in, const dt_iop_roi_t *roi_out)
+               const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
 {
   dt_iop_atrous_data_t *d = (dt_iop_atrous_data_t *)piece->data;
   float thrs[MAX_NUM_SCALES][4];
@@ -540,8 +788,7 @@ int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_m
   cl_int err = -999;
   cl_mem dev_filter = NULL;
   cl_mem dev_tmp = NULL;
-  cl_mem dev_detail[max_scale];
-  for(int k = 0; k < max_scale; k++) dev_detail[k] = NULL;
+  cl_mem *dev_detail = calloc(max_scale, sizeof(cl_mem));
 
   float m[] = { 0.0625f, 0.25f, 0.375f, 0.25f, 0.0625f }; // 1/16, 4/16, 6/16, 4/16, 1/16
   float mm[5][5];
@@ -639,17 +886,19 @@ int process_cl(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, cl_m
   if(!darktable.opencl->async_pixelpipe || piece->pipe->type == DT_DEV_PIXELPIPE_EXPORT)
     dt_opencl_finish(devid);
 
-  if(dev_filter != NULL) dt_opencl_release_mem_object(dev_filter);
-  if(dev_tmp != NULL) dt_opencl_release_mem_object(dev_tmp);
+  dt_opencl_release_mem_object(dev_filter);
+  dt_opencl_release_mem_object(dev_tmp);
   for(int k = 0; k < max_scale; k++)
-    if(dev_detail[k] != NULL) dt_opencl_release_mem_object(dev_detail[k]);
+    dt_opencl_release_mem_object(dev_detail[k]);
+  free(dev_detail);
   return TRUE;
 
 error:
-  if(dev_filter != NULL) dt_opencl_release_mem_object(dev_filter);
-  if(dev_tmp != NULL) dt_opencl_release_mem_object(dev_tmp);
+  dt_opencl_release_mem_object(dev_filter);
+  dt_opencl_release_mem_object(dev_tmp);
   for(int k = 0; k < max_scale; k++)
-    if(dev_detail[k] != NULL) dt_opencl_release_mem_object(dev_detail[k]);
+    dt_opencl_release_mem_object(dev_detail[k]);
+  free(dev_detail);
   dt_print(DT_DEBUG_OPENCL, "[opencl_atrous] couldn't enqueue kernel! %d\n", err);
   return FALSE;
 }
@@ -680,7 +929,7 @@ void init(dt_iop_module_t *module)
   module->params = calloc(1, sizeof(dt_iop_atrous_params_t));
   module->default_params = calloc(1, sizeof(dt_iop_atrous_params_t));
   module->default_enabled = 0;
-  module->priority = 550; // module order created by iop_dependencies.py, do not edit!
+  module->priority = 567; // module order created by iop_dependencies.py, do not edit!
   module->params_size = sizeof(dt_iop_atrous_params_t);
   module->gui_data = NULL;
   dt_iop_atrous_params_t tmp;
@@ -770,7 +1019,7 @@ void cleanup_pipe(struct dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev
 
 void init_presets(dt_iop_module_so_t *self)
 {
-  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "begin", NULL, NULL, NULL);
+  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "BEGIN", NULL, NULL, NULL);
   dt_iop_atrous_params_t p;
   p.octaves = 7;
 
@@ -873,7 +1122,7 @@ void init_presets(dt_iop_module_so_t *self)
     p.y[atrous_ct][k] = 0.0f;
   }
   dt_gui_presets_add_generic(_("clarity"), self->op, self->version(), &p, sizeof(p), 1);
-  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "commit", NULL, NULL, NULL);
+  DT_DEBUG_SQLITE3_EXEC(dt_database_get(darktable.db), "COMMIT", NULL, NULL, NULL);
 }
 
 static void reset_mix(dt_iop_module_t *self)
@@ -929,9 +1178,9 @@ static gboolean area_draw(GtkWidget *widget, cairo_t *crf, gpointer user_data)
   dt_iop_module_t *self = (dt_iop_module_t *)user_data;
   dt_iop_atrous_gui_data_t *c = (dt_iop_atrous_gui_data_t *)self->gui_data;
   dt_iop_atrous_params_t p = *(dt_iop_atrous_params_t *)self->params;
-  int ch = (int)c->channel;
-  int ch2 = (int)c->channel2;
-  for(int k = 0; k < BANDS; k++) dt_draw_curve_set_point(c->minmax_curve, k, p.x[ch2][k], p.y[ch2][k]);
+
+  for(int k = 0; k < BANDS; k++)
+    dt_draw_curve_set_point(c->minmax_curve, k, p.x[(int)c->channel2][k], p.y[(int)c->channel2][k]);
   const int inset = INSET;
   GtkAllocation allocation;
   gtk_widget_get_allocation(widget, &allocation);
@@ -977,6 +1226,8 @@ static gboolean area_draw(GtkWidget *widget, cairo_t *crf, gpointer user_data)
 
   if(c->mouse_y > 0 || c->dragging)
   {
+    int ch2 = (int)c->channel2;
+
     // draw min/max curves:
     get_params(&p, ch2, c->mouse_x, 1., c->mouse_radius);
     for(int k = 0; k < BANDS; k++) dt_draw_curve_set_point(c->minmax_curve, k, p.x[ch2][k], p.y[ch2][k]);
@@ -1090,6 +1341,9 @@ static gboolean area_draw(GtkWidget *widget, cairo_t *crf, gpointer user_data)
 
   if(c->mouse_y > 0 || c->dragging)
   {
+    int ch = (int)c->channel;
+    int ch2 = (int)c->channel2;
+
     // draw dots on knots
     cairo_save(cr);
     if(ch != ch2)
@@ -1137,7 +1391,7 @@ static gboolean area_draw(GtkWidget *widget, cairo_t *crf, gpointer user_data)
   const float arrw = DT_PIXEL_APPLY_DPI(7.0f);
   for(int k = 1; k < BANDS - 1; k++)
   {
-    cairo_move_to(cr, width * p.x[ch][k], inset - DT_PIXEL_APPLY_DPI(1));
+    cairo_move_to(cr, width * p.x[(int)c->channel][k], inset - DT_PIXEL_APPLY_DPI(1));
     cairo_rel_line_to(cr, -arrw * .5f, 0);
     cairo_rel_line_to(cr, arrw * .5f, -arrw);
     cairo_rel_line_to(cr, arrw * .5f, arrw);
@@ -1153,40 +1407,50 @@ static gboolean area_draw(GtkWidget *widget, cairo_t *crf, gpointer user_data)
   if(c->mouse_y > 0 || c->dragging)
   {
     // draw labels:
-    cairo_text_extents_t ext;
+    PangoLayout *layout;
+    PangoRectangle ink;
+    PangoFontDescription *desc = pango_font_description_copy_static(darktable.bauhaus->pango_font_desc);
+    pango_font_description_set_weight(desc, PANGO_WEIGHT_BOLD);
+    pango_font_description_set_absolute_size(desc, (.06 * height) * PANGO_SCALE);
+    layout = pango_cairo_create_layout(cr);
+    pango_layout_set_font_description(layout, desc);
     gdk_cairo_set_source_rgba(cr, &really_dark_bg_color);
     cairo_select_font_face(cr, "sans-serif", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
     cairo_set_font_size(cr, .06 * height);
-    cairo_text_extents(cr, _("coarse"), &ext);
-    cairo_move_to(cr, .02 * width + ext.height, .14 * height + ext.width);
+    pango_layout_set_text(layout, _("coarse"), -1);
+    pango_layout_get_pixel_extents(layout, &ink, NULL);
+    cairo_move_to(cr, .02 * width - ink.y, .14 * height + ink.width);
     cairo_save(cr);
     cairo_rotate(cr, -M_PI * .5f);
-    cairo_show_text(cr, _("coarse"));
+    pango_cairo_show_layout(cr, layout);
     cairo_restore(cr);
-    cairo_text_extents(cr, _("fine"), &ext);
-    cairo_move_to(cr, .98 * width, .14 * height + ext.width);
+    pango_layout_set_text(layout, _("fine"), -1);
+    pango_layout_get_pixel_extents(layout, &ink, NULL);
+    cairo_move_to(cr, .98 * width - ink.height, .14 * height + ink.width);
     cairo_save(cr);
     cairo_rotate(cr, -M_PI * .5f);
-    cairo_show_text(cr, _("fine"));
+    pango_cairo_show_layout(cr, layout);
     cairo_restore(cr);
 
     switch(c->channel2)
     {
       case atrous_L:
       case atrous_c:
-        dt_atrous_show_upper_label(cr, _("contrasty"), ext);
-        dt_atrous_show_lower_label(cr, _("smooth"), ext);
+        dt_atrous_show_upper_label(cr, _("contrasty"), layout, ink);
+        dt_atrous_show_lower_label(cr, _("smooth"), layout, ink);
         break;
       case atrous_Lt:
       case atrous_ct:
-        dt_atrous_show_upper_label(cr, _("smooth"), ext);
-        dt_atrous_show_lower_label(cr, _("noisy"), ext);
+        dt_atrous_show_upper_label(cr, _("smooth"), layout, ink);
+        dt_atrous_show_lower_label(cr, _("noisy"), layout, ink);
         break;
       default: // case atrous_s:
-        dt_atrous_show_upper_label(cr, _("bold"), ext);
-        dt_atrous_show_lower_label(cr, _("dull"), ext);
+        dt_atrous_show_upper_label(cr, _("bold"), layout, ink);
+        dt_atrous_show_lower_label(cr, _("dull"), layout, ink);
         break;
     }
+    pango_font_description_free(desc);
+    g_object_unref(layout);
   }
 
 
@@ -1269,9 +1533,9 @@ static gboolean area_motion_notify(GtkWidget *widget, GdkEventMotion *event, gpo
   gtk_widget_queue_draw(widget);
   gint x, y;
 #if GTK_CHECK_VERSION(3, 20, 0)
-  gdk_window_get_device_position(
-      event->window, gdk_seat_get_pointer(gdk_display_get_default_seat(gtk_widget_get_display(widget))), &x,
-      &y, 0);
+  gdk_window_get_device_position(event->window,
+      gdk_seat_get_pointer(gdk_display_get_default_seat(gtk_widget_get_display(widget))),
+      &x, &y, 0);
 #else
   gdk_window_get_device_position(event->window,
                                  gdk_device_manager_get_client_pointer(
@@ -1391,21 +1655,17 @@ void gui_init(struct dt_iop_module_t *self)
 
   gtk_notebook_append_page(GTK_NOTEBOOK(c->channel_tabs),
                            GTK_WIDGET(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0)), gtk_label_new(_("luma")));
-  g_object_set(
-      G_OBJECT(gtk_notebook_get_tab_label(c->channel_tabs, gtk_notebook_get_nth_page(c->channel_tabs, -1))),
-      "tooltip-text", _("change lightness at each feature size"), NULL);
+  gtk_widget_set_tooltip_text(gtk_notebook_get_tab_label(c->channel_tabs, gtk_notebook_get_nth_page(c->channel_tabs, -1)),
+                              _("change lightness at each feature size"));
   gtk_notebook_append_page(GTK_NOTEBOOK(c->channel_tabs),
                            GTK_WIDGET(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0)),
                            gtk_label_new(_("chroma")));
-  g_object_set(
-      G_OBJECT(gtk_notebook_get_tab_label(c->channel_tabs, gtk_notebook_get_nth_page(c->channel_tabs, -1))),
-      "tooltip-text", _("change color saturation at each feature size"), NULL);
+  gtk_widget_set_tooltip_text(gtk_notebook_get_tab_label(c->channel_tabs, gtk_notebook_get_nth_page(c->channel_tabs, -1)),
+                              _("change color saturation at each feature size"));
   gtk_notebook_append_page(GTK_NOTEBOOK(c->channel_tabs),
                            GTK_WIDGET(gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0)), gtk_label_new(_("edges")));
-  g_object_set(
-      G_OBJECT(gtk_notebook_get_tab_label(c->channel_tabs, gtk_notebook_get_nth_page(c->channel_tabs, -1))),
-      "tooltip-text",
-      _("change edge halos at each feature size\nonly changes results of luma and chroma tabs"), NULL);
+  gtk_widget_set_tooltip_text(gtk_notebook_get_tab_label(c->channel_tabs, gtk_notebook_get_nth_page(c->channel_tabs, -1)),
+                              _("change edge halos at each feature size\nonly changes results of luma and chroma tabs"));
 
   gtk_widget_show_all(GTK_WIDGET(gtk_notebook_get_nth_page(c->channel_tabs, c->channel)));
   gtk_notebook_set_current_page(GTK_NOTEBOOK(c->channel_tabs), c->channel);
@@ -1432,7 +1692,7 @@ void gui_init(struct dt_iop_module_t *self)
   // mix slider
   c->mix = dt_bauhaus_slider_new_with_range(self, -2.0f, 2.0f, 0.1f, 1.0f, 3);
   dt_bauhaus_widget_set_label(c->mix, NULL, _("mix"));
-  g_object_set(G_OBJECT(c->mix), "tooltip-text", _("make effect stronger or weaker"), (char *)NULL);
+  gtk_widget_set_tooltip_text(c->mix, _("make effect stronger or weaker"));
   gtk_box_pack_start(GTK_BOX(self->widget), c->mix, TRUE, TRUE, 0);
   g_signal_connect(G_OBJECT(c->mix), "value-changed", G_CALLBACK(mix_callback), self);
 }
@@ -1448,4 +1708,4 @@ void gui_cleanup(struct dt_iop_module_t *self)
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
