@@ -941,7 +941,7 @@ static gboolean _lib_plugin_header_button_press(GtkWidget *w, GdkEventButton *e,
       {
         dt_lib_module_t *m = (dt_lib_module_t *)it->data;
 
-        if(m != module && container == m->container(module) && m->expandable(module) && (m->views(module) & v->view(v)))
+        if(m != module && container == m->container(m) && m->expandable(m) && (m->views(module) & v->view(v)))
         {
           all_other_closed = all_other_closed && !dtgtk_expander_get_expanded(DTGTK_EXPANDER(m->expander));
           dt_lib_gui_set_expanded(m, FALSE);
