@@ -16,19 +16,19 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef DT_LIB_H
-#define DT_LIB_H
+
+#pragma once
 
 #include "common/darktable.h"
 #include "views/view.h"
 #include <gmodule.h>
 #include <gtk/gtk.h>
 #ifdef USE_LUA
-#include "lua/types.h"
-#include "lua/modules.h"
-#include "lua/lib.h"
-#include "lua/events.h"
 #include "lua/call.h"
+#include "lua/events.h"
+#include "lua/lib.h"
+#include "lua/modules.h"
+#include "lua/types.h"
 #endif
 
 struct dt_lib_module_t;
@@ -69,6 +69,8 @@ typedef struct dt_lib_t
 
 typedef struct dt_lib_module_t
 {
+  // !!! MUST BE KEPT IN SYNC WITH src/libs/lib_api.h !!!
+
   /** opened module. */
   GModule *module;
   /** reference for dlopened libs. */
@@ -121,7 +123,7 @@ typedef struct dt_lib_module_t
                         int type, uint32_t state);
   int (*scrolled)(struct dt_lib_module_t *self, double x, double y, int up);
   void (*configure)(struct dt_lib_module_t *self, int width, int height);
-  int (*position)();
+  int (*position)(const struct dt_lib_module_t *self);
   /** implement these three if you want customizable presets to be stored in db. */
   /** legacy_params can run in iterations, just return to what version you updated the preset. */
   void *(*legacy_params)(struct dt_lib_module_t *self, const void *const old_params,
@@ -184,8 +186,6 @@ gint dt_lib_sort_plugins(gconstpointer a, gconstpointer b);
 /** init presets for a newly created lib */
 void dt_lib_init_presets(dt_lib_module_t *module);
 
-#endif
-
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
