@@ -16,14 +16,16 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "bauhaus/bauhaus.h"
 #include "common/darktable.h"
 #include "common/debug.h"
-#include "control/control.h"
-#include "control/conf.h"
 #include "common/image_cache.h"
+#include "control/conf.h"
+#include "control/control.h"
 #include "develop/develop.h"
-#include "libs/lib.h"
 #include "gui/gtk.h"
+#include "libs/lib.h"
+#include "libs/lib_api.h"
 
 DT_MODULE(1)
 
@@ -58,22 +60,22 @@ static gboolean _lib_navigation_leave_notify_callback(GtkWidget *widget, GdkEven
 /* helper function for position set */
 static void _lib_navigation_set_position(struct dt_lib_module_t *self, double x, double y, int wd, int ht);
 
-const char *name()
+const char *name(dt_lib_module_t *self)
 {
   return _("navigation");
 }
 
-uint32_t views()
+uint32_t views(dt_lib_module_t *self)
 {
   return DT_VIEW_DARKROOM;
 }
 
-uint32_t container()
+uint32_t container(dt_lib_module_t *self)
 {
   return DT_UI_CONTAINER_PANEL_LEFT_TOP;
 }
 
-int expandable()
+int expandable(dt_lib_module_t *self)
 {
   return 0;
 }
@@ -236,7 +238,7 @@ static gboolean _lib_navigation_draw_callback(GtkWidget *widget, cairo_t *crf, g
       dt_dev_check_zoom_bounds(darktable.develop, &zoom_x, &zoom_y, zoom, closeup, &boxw, &boxh);
       cairo_translate(cr, wd * (.5f + zoom_x), ht * (.5f + zoom_y));
       cairo_set_source_rgb(cr, 0., 0., 0.);
-      cairo_set_line_width(cr, 1.f / scale);
+      cairo_set_line_width(cr, DT_PIXEL_APPLY_DPI(1.f / scale));
       boxw *= wd;
       boxh *= ht;
       cairo_rectangle(cr, -boxw / 2 - 1, -boxh / 2 - 1, boxw + 2, boxh + 2);
@@ -249,46 +251,70 @@ static gboolean _lib_navigation_draw_callback(GtkWidget *widget, cairo_t *crf, g
     if(fabsf(cur_scale - min_scale) > 0.001f)
     {
       /* Zoom % */
+      PangoLayout *layout;
+      PangoRectangle ink;
+      PangoFontDescription *desc = pango_font_description_copy_static(darktable.bauhaus->pango_font_desc);
+      pango_font_description_set_weight(desc, PANGO_WEIGHT_BOLD);
+      layout = pango_cairo_create_layout(cr);
+      const float fontsize = DT_PIXEL_APPLY_DPI(11);
+      pango_font_description_set_absolute_size(desc, fontsize * PANGO_SCALE);
+      pango_layout_set_font_description(layout, desc);
       cairo_translate(cr, 0, height);
       cairo_set_source_rgba(cr, 1., 1., 1., 0.5);
-      cairo_select_font_face(cr, "sans-serif", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-      cairo_set_font_size(cr, DT_PIXEL_APPLY_DPI(11));
+      cairo_set_line_join(cr, CAIRO_LINE_JOIN_ROUND);
 
       char zoomline[5];
       snprintf(zoomline, sizeof(zoomline), "%.0f%%", cur_scale * 100);
 
-      cairo_text_extents_t ext;
-      cairo_text_extents(cr, zoomline, &ext);
-      h = d->zoom_h = ext.height;
-      w = d->zoom_w = ext.width;
+      pango_layout_set_text(layout, zoomline, -1);
+      pango_layout_get_pixel_extents(layout, &ink, NULL);
+      h = d->zoom_h = ink.height;
+      w = d->zoom_w = ink.width;
 
-      cairo_move_to(cr, width - w - h * 1.1, 0);
+      cairo_move_to(cr, width - w - h * 1.1 - ink.x, - fontsize);
 
       cairo_save(cr);
-      cairo_set_line_width(cr, 2.0);
+      cairo_set_line_width(cr, DT_PIXEL_APPLY_DPI(2.0));
 
       GdkRGBA *color;
       gtk_style_context_get(context, gtk_widget_get_state_flags(widget), "background-color", &color, NULL);
 
       gdk_cairo_set_source_rgba(cr, color);
-      cairo_text_path(cr, zoomline);
+      pango_cairo_layout_path(cr, layout);
       cairo_stroke_preserve(cr);
       cairo_set_source_rgb(cr, 0.6, 0.6, 0.6);
       cairo_fill(cr);
       cairo_restore(cr);
 
       gdk_rgba_free(color);
+      pango_font_description_free(desc);
+      g_object_unref(layout);
+
     }
     else
     {
       // draw the zoom-to-fit icon
       cairo_translate(cr, 0, height);
       cairo_set_source_rgb(cr, 0.6, 0.6, 0.6);
-      cairo_text_extents_t ext;
-      cairo_select_font_face(cr, "sans-serif", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_BOLD);
-      cairo_set_font_size(cr, DT_PIXEL_APPLY_DPI(11));
-      cairo_text_extents(cr, "100%", &ext); // dummy text, just to get the height
-      h = d->zoom_h = ext.height;
+
+      static int font_height = -1;
+      if(font_height == -1)
+      {
+        PangoLayout *layout;
+        PangoRectangle ink;
+        PangoFontDescription *desc = pango_font_description_copy_static(darktable.bauhaus->pango_font_desc);
+        pango_font_description_set_weight(desc, PANGO_WEIGHT_BOLD);
+        layout = pango_cairo_create_layout(cr);
+        pango_font_description_set_absolute_size(desc, DT_PIXEL_APPLY_DPI(11) * PANGO_SCALE);
+        pango_layout_set_font_description(layout, desc);
+        pango_layout_set_text(layout, "100%", -1); // dummy text, just to get the height
+        pango_layout_get_pixel_extents(layout, &ink, NULL);
+        font_height = ink.height;
+        pango_font_description_free(desc);
+        g_object_unref(layout);
+      }
+
+      h = d->zoom_h = font_height;
       w = h * 1.5;
       float sp = h * 0.6;
       d->zoom_w = w + sp;
@@ -298,6 +324,8 @@ static gboolean _lib_navigation_draw_callback(GtkWidget *widget, cairo_t *crf, g
       cairo_set_source_rgb(cr, 0.2, 0.2, 0.2);
       cairo_fill(cr);
 
+      cairo_set_line_width(cr, DT_PIXEL_APPLY_DPI(2.0));
+
       cairo_set_source_rgb(cr, 0.6, 0.6, 0.6);
       cairo_move_to(cr, width - w * 0.8 - h - sp, -1.0 * h);
       cairo_line_to(cr, width - w - h - sp, -1.0 * h);
@@ -376,9 +404,10 @@ static gboolean _lib_navigation_motion_notify_callback(GtkWidget *widget, GdkEve
   _lib_navigation_set_position(self, event->x, event->y, allocation.width, allocation.height);
   gint x, y; // notify gtk for motion_hint.
 #if GTK_CHECK_VERSION(3, 20, 0)
-  gdk_window_get_device_position(
-      event->window,
-      gdk_seat_get_pointer(gdk_display_get_default_seat(gdk_window_get_display(event->window))), &x, &y, 0);
+  gdk_window_get_device_position(event->window,
+      gdk_seat_get_pointer(gdk_display_get_default_seat(
+          gdk_window_get_display(event->window))),
+      &x, &y, 0);
 #else
   gdk_window_get_device_position(event->window,
                                  gdk_device_manager_get_client_pointer(
@@ -486,7 +515,12 @@ static gboolean _lib_navigation_button_press_callback(GtkWidget *widget, GdkEven
     gtk_menu_shell_append(menu, item);
 
     gtk_widget_show_all(GTK_WIDGET(menu));
+
+#if GTK_CHECK_VERSION(3, 22, 0)
+    gtk_menu_popup_at_pointer(GTK_MENU(menu), (GdkEvent *)event);
+#else
     gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time());
+#endif
 
     return TRUE;
   }
@@ -512,4 +546,4 @@ static gboolean _lib_navigation_leave_notify_callback(GtkWidget *widget, GdkEven
 }
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
