@@ -16,15 +16,16 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "common/darktable.h"
 #include "common/collection.h"
-#include "libs/lib.h"
-#include "gui/accelerators.h"
-#include "gui/preferences.h"
-#include "dtgtk/button.h"
-#include "dtgtk/togglebutton.h"
+#include "common/darktable.h"
 #include "control/conf.h"
 #include "control/control.h"
+#include "dtgtk/button.h"
+#include "dtgtk/togglebutton.h"
+#include "gui/accelerators.h"
+#include "gui/preferences.h"
+#include "libs/lib.h"
+#include "libs/lib_api.h"
 
 DT_MODULE(1)
 
@@ -40,22 +41,22 @@ static void _lib_preferences_button_clicked(GtkWidget *widget, gpointer user_dat
 /* callback for overlays button */
 static void _lib_overlays_button_clicked(GtkWidget *widget, gpointer user_data);
 
-const char *name()
+const char *name(dt_lib_module_t *self)
 {
   return _("preferences");
 }
 
-uint32_t views()
+uint32_t views(dt_lib_module_t *self)
 {
   return DT_VIEW_DARKROOM | DT_VIEW_LIGHTTABLE | DT_VIEW_TETHERING | DT_VIEW_MAP | DT_VIEW_PRINT;
 }
 
-uint32_t container()
+uint32_t container(dt_lib_module_t *self)
 {
   return DT_UI_CONTAINER_PANEL_CENTER_TOP_RIGHT;
 }
 
-int expandable()
+int expandable(dt_lib_module_t *self)
 {
   return 0;
 }
@@ -78,9 +79,9 @@ void gui_init(dt_lib_module_t *self)
   gtk_widget_set_size_request(d->grouping_button, DT_PIXEL_APPLY_DPI(18), DT_PIXEL_APPLY_DPI(18));
   gtk_box_pack_start(GTK_BOX(self->widget), d->grouping_button, FALSE, FALSE, 2);
   if(darktable.gui->grouping)
-    g_object_set(G_OBJECT(d->grouping_button), "tooltip-text", _("expand grouped images"), (char *)NULL);
+    gtk_widget_set_tooltip_text(d->grouping_button, _("expand grouped images"));
   else
-    g_object_set(G_OBJECT(d->grouping_button), "tooltip-text", _("collapse grouped images"), (char *)NULL);
+    gtk_widget_set_tooltip_text(d->grouping_button, _("collapse grouped images"));
   g_signal_connect(G_OBJECT(d->grouping_button), "clicked", G_CALLBACK(_lib_filter_grouping_button_clicked),
                    NULL);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->grouping_button), darktable.gui->grouping);
@@ -90,9 +91,9 @@ void gui_init(dt_lib_module_t *self)
   gtk_widget_set_size_request(d->overlays_button, DT_PIXEL_APPLY_DPI(18), DT_PIXEL_APPLY_DPI(18));
   gtk_box_pack_start(GTK_BOX(self->widget), d->overlays_button, FALSE, FALSE, 2);
   if(darktable.gui->show_overlays)
-    g_object_set(G_OBJECT(d->overlays_button), "tooltip-text", _("hide image overlays"), (char *)NULL);
+    gtk_widget_set_tooltip_text(d->overlays_button, _("hide image overlays"));
   else
-    g_object_set(G_OBJECT(d->overlays_button), "tooltip-text", _("show image overlays"), (char *)NULL);
+    gtk_widget_set_tooltip_text(d->overlays_button, _("show image overlays"));
   g_signal_connect(G_OBJECT(d->overlays_button), "clicked", G_CALLBACK(_lib_overlays_button_clicked), NULL);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(d->overlays_button), darktable.gui->show_overlays);
 
@@ -100,7 +101,7 @@ void gui_init(dt_lib_module_t *self)
   d->preferences_button = dtgtk_button_new(dtgtk_cairo_paint_preferences, CPF_STYLE_FLAT);
   gtk_widget_set_size_request(d->preferences_button, DT_PIXEL_APPLY_DPI(18), DT_PIXEL_APPLY_DPI(18));
   gtk_box_pack_end(GTK_BOX(self->widget), d->preferences_button, FALSE, FALSE, 2);
-  g_object_set(G_OBJECT(d->preferences_button), "tooltip-text", _("show global preferences"), (char *)NULL);
+  gtk_widget_set_tooltip_text(d->preferences_button, _("show global preferences"));
   g_signal_connect(G_OBJECT(d->preferences_button), "clicked", G_CALLBACK(_lib_preferences_button_clicked),
                    NULL);
 }
@@ -121,15 +122,16 @@ static void _lib_filter_grouping_button_clicked(GtkWidget *widget, gpointer user
 
   darktable.gui->grouping = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
   if(darktable.gui->grouping)
-    g_object_set(G_OBJECT(widget), "tooltip-text", _("expand grouped images"), (char *)NULL);
+    gtk_widget_set_tooltip_text(widget, _("expand grouped images"));
   else
-    g_object_set(G_OBJECT(widget), "tooltip-text", _("collapse grouped images"), (char *)NULL);
+    gtk_widget_set_tooltip_text(widget, _("collapse grouped images"));
   dt_conf_set_bool("ui_last/grouping", darktable.gui->grouping);
   darktable.gui->expanded_group_id = -1;
   dt_collection_update_query(darktable.collection);
 
 #ifdef USE_LUA
-  dt_lua_do_chunk_async(dt_lua_event_trigger_wrapper,
+  dt_lua_async_call_alien(dt_lua_event_trigger_wrapper,
+      0,NULL,NULL,
       LUA_ASYNC_TYPENAME,"const char*","global_toolbox-grouping_toggle",
       LUA_ASYNC_TYPENAME,"bool",darktable.gui->grouping,
       LUA_ASYNC_DONE);
@@ -140,14 +142,15 @@ static void _lib_overlays_button_clicked(GtkWidget *widget, gpointer user_data)
 {
   darktable.gui->show_overlays = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
   if(darktable.gui->show_overlays)
-    g_object_set(G_OBJECT(widget), "tooltip-text", _("hide image overlays"), (char *)NULL);
+    gtk_widget_set_tooltip_text(widget, _("hide image overlays"));
   else
-    g_object_set(G_OBJECT(widget), "tooltip-text", _("show image overlays"), (char *)NULL);
+    gtk_widget_set_tooltip_text(widget, _("show image overlays"));
   dt_conf_set_bool("lighttable/ui/expose_statuses", darktable.gui->show_overlays);
   dt_control_signal_raise(darktable.signals, DT_SIGNAL_COLLECTION_CHANGED);
 
 #ifdef USE_LUA
-  dt_lua_do_chunk_async(dt_lua_event_trigger_wrapper,
+  dt_lua_async_call_alien(dt_lua_event_trigger_wrapper,
+      0,NULL,NULL,
       LUA_ASYNC_TYPENAME,"const char*","global_toolbox-overlay_toggle",
       LUA_ASYNC_TYPENAME,"bool",darktable.gui->show_overlays,
       LUA_ASYNC_DONE);
@@ -218,10 +221,10 @@ void init(struct dt_lib_module_t *self)
   int my_type = dt_lua_module_entry_get_type(L, "lib", self->plugin_name);
 
   lua_pushcfunction(L, grouping_member);
-  lua_pushcclosure(L,dt_lua_gtk_wrap,1);
+  dt_lua_gtk_wrap(L);
   dt_lua_type_register_type(L, my_type, "grouping");
   lua_pushcfunction(L, show_overlays_member);
-  lua_pushcclosure(L,dt_lua_gtk_wrap,1);
+  dt_lua_gtk_wrap(L);
   dt_lua_type_register_type(L, my_type, "show_overlays");
 
   lua_pushcfunction(L, dt_lua_event_multiinstance_register);
@@ -237,4 +240,4 @@ void init(struct dt_lib_module_t *self)
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
