@@ -1,4 +1,3 @@
-
 /*
     This file is part of darktable,
     copyright (c) 2015 Jeremy Rosen
@@ -16,12 +15,13 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef DT_LUA_LUALIB_H
-#define DT_LUA_LUALIB_H
+
+#pragma once
+
 #include "lua/lua.h"
 
 int dt_lua_init_lualib(lua_State *L);
-#endif
+
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
