@@ -15,10 +15,11 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef DT_LUA_VIEW_H
-#define DT_LUA_VIEW_H
-#include <lua/lua.h>
+
+#pragma once
+
 #include "views/view.h"
+#include <lua/lua.h>
 
 
 
@@ -31,7 +32,6 @@ void dt_lua_register_view(lua_State *L, struct dt_view_t *self);
 int dt_lua_init_early_view(lua_State *L);
 int dt_lua_init_view(lua_State *L);
 
-#endif
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
