@@ -17,25 +17,32 @@
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "control/control.h"
-#include "control/conf.h"
-#include "common/debug.h"
 #include "common/collection.h"
 #include "common/darktable.h"
+#include "common/debug.h"
+#include "common/geo.h"
 #include "common/image_cache.h"
 #include "common/mipmap_cache.h"
-#include "views/view.h"
-#include "views/undo.h"
-#include "libs/lib.h"
+#include "control/conf.h"
+#include "control/control.h"
+#include "gui/accelerators.h"
 #include "gui/drag_and_drop.h"
 #include "gui/draw.h"
-#include "gui/accelerators.h"
+#include "libs/lib.h"
+#include "views/undo.h"
+#include "views/view.h"
+#include "views/view_api.h"
 #include <gdk/gdkkeysyms.h>
 
 #include <osm-gps-map.h>
 
 DT_MODULE(1)
 
+typedef struct dt_undo_geotag_t
+{
+  int imgid;
+  float longitude, latitude, elevation;
+} dt_undo_geotag_t;
 
 typedef struct dt_map_t
 {
@@ -44,7 +51,7 @@ typedef struct dt_map_t
   OsmGpsMapSource_t map_source;
   OsmGpsMapLayer *osd;
   GSList *images;
-  GdkPixbuf *pin;
+  GdkPixbuf *image_pin, *place_pin;
   gint selected_image;
   gboolean start_drag;
   struct
@@ -63,8 +70,11 @@ typedef struct dt_map_image_t
   gint width, height;
 } dt_map_image_t;
 
-static const int thumb_size = 64, thumb_border = 1, pin_size = 13;
+static const int thumb_size = 64, thumb_border = 1, image_pin_size = 13, place_pin_size = 72;
 static const uint32_t thumb_frame_color = 0x000000aa;
+static const uint32_t pin_outer_color = 0x0000aaaa;
+static const uint32_t pin_inner_color = 0xffffffee;
+static const uint32_t pin_line_color = 0x000000ff;
 
 /* proxy function to center map view on location at a zoom level */
 static void _view_map_center_on_location(const dt_view_t *view, gdouble lon, gdouble lat, gdouble zoom);
@@ -78,6 +88,10 @@ static void _view_map_set_map_source(const dt_view_t *view, OsmGpsMapSource_t ma
 static void _view_map_set_map_source_g_object(const dt_view_t *view, OsmGpsMapSource_t map_source);
 /* proxy function to check if preferences have changed */
 static void _view_map_check_preference_changed(gpointer instance, gpointer user_data);
+/* proxy function to add a marker to the map */
+static GObject *_view_map_add_marker(const dt_view_t *view, dt_geo_map_display_t type, GList *points);
+/* proxy function to remove a marker from the map */
+static gboolean _view_map_remove_marker(const dt_view_t *view, dt_geo_map_display_t type, GObject *marker);
 
 /* callback when the collection changs */
 static void _view_map_collection_changed(gpointer instance, gpointer user_data);
@@ -115,7 +129,7 @@ const char *name(dt_view_t *self)
   return _("map");
 }
 
-uint32_t view(dt_view_t *self)
+uint32_t view(const dt_view_t *self)
 {
   return DT_VIEW_MAP;
 }
@@ -283,9 +297,9 @@ static void osm_gps_map_zoom_fit_bbox(OsmGpsMap *map, float latitude1, float lat
 }
 #endif // HAVE_OSMGPSMAP_110_OR_NEWER
 
-static GdkPixbuf *init_pin()
+static GdkPixbuf *init_image_pin()
 {
-  int w = DT_PIXEL_APPLY_DPI(thumb_size + 2 * thumb_border), h = DT_PIXEL_APPLY_DPI(pin_size);
+  int w = DT_PIXEL_APPLY_DPI(thumb_size + 2 * thumb_border), h = DT_PIXEL_APPLY_DPI(image_pin_size);
   float r, g, b, a;
   r = ((thumb_frame_color & 0xff000000) >> 24) / 255.0;
   g = ((thumb_frame_color & 0x00ff0000) >> 16) / 255.0;
@@ -299,8 +313,61 @@ static GdkPixbuf *init_pin()
   cairo_destroy(cr);
   uint8_t *data = cairo_image_surface_get_data(cst);
   dt_draw_cairo_to_gdk_pixbuf(data, w, h);
-  return gdk_pixbuf_new_from_data(data, GDK_COLORSPACE_RGB, TRUE, 8, w, h, w * 4,
-                                  (GdkPixbufDestroyNotify)free, NULL);
+  size_t size = w * h * 4;
+  uint8_t *buf = (uint8_t *)malloc(size);
+  memcpy(buf, data, size);
+  GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data(buf, GDK_COLORSPACE_RGB, TRUE, 8, w, h, w * 4,
+                                               (GdkPixbufDestroyNotify)free, NULL);
+  cairo_surface_destroy(cst);
+  return pixbuf;
+}
+
+static GdkPixbuf *init_place_pin()
+{
+  int w = DT_PIXEL_APPLY_DPI(place_pin_size), h = DT_PIXEL_APPLY_DPI(place_pin_size);
+  float r, g, b, a;
+
+  cairo_surface_t *cst = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, w, h);
+  cairo_t *cr = cairo_create(cst);
+
+  // outer shape
+  r = ((pin_outer_color & 0xff000000) >> 24) / 255.0;
+  g = ((pin_outer_color & 0x00ff0000) >> 16) / 255.0;
+  b = ((pin_outer_color & 0x0000ff00) >> 8) / 255.0;
+  a = ((pin_outer_color & 0x000000ff) >> 0) / 255.0;
+  cairo_set_source_rgba(cr, r, g, b, a);
+  cairo_arc(cr, 0.5 * w, 0.333 * h, 0.333 * h - 2, 150.0 * (M_PI / 180.0), 30.0 * (M_PI / 180.0));
+  cairo_line_to(cr, 0.5 * w, h - 2);
+  cairo_close_path(cr);
+  cairo_fill_preserve(cr);
+
+  r = ((pin_line_color & 0xff000000) >> 24) / 255.0;
+  g = ((pin_line_color & 0x00ff0000) >> 16) / 255.0;
+  b = ((pin_line_color & 0x0000ff00) >> 8) / 255.0;
+  a = ((pin_line_color & 0x000000ff) >> 0) / 255.0;
+  cairo_set_source_rgba(cr, r, g, b, a);
+  cairo_set_line_width(cr, DT_PIXEL_APPLY_DPI(1));
+  cairo_stroke(cr);
+
+  // inner circle
+  r = ((pin_inner_color & 0xff000000) >> 24) / 255.0;
+  g = ((pin_inner_color & 0x00ff0000) >> 16) / 255.0;
+  b = ((pin_inner_color & 0x0000ff00) >> 8) / 255.0;
+  a = ((pin_inner_color & 0x000000ff) >> 0) / 255.0;
+  cairo_set_source_rgba(cr, r, g, b, a);
+  cairo_arc(cr, 0.5 * w, 0.333 * h, 0.17 * h, 0, 2.0 * M_PI);
+  cairo_fill(cr);
+
+  cairo_destroy(cr);
+  uint8_t *data = cairo_image_surface_get_data(cst);
+  dt_draw_cairo_to_gdk_pixbuf(data, w, h);
+  size_t size = w * h * 4;
+  uint8_t *buf = (uint8_t *)malloc(size);
+  memcpy(buf, data, size);
+  GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data(buf, GDK_COLORSPACE_RGB, TRUE, 8, w, h, w * 4,
+                                               (GdkPixbufDestroyNotify)free, NULL);
+  cairo_surface_destroy(cst);
+  return pixbuf;
 }
 
 void init(dt_view_t *self)
@@ -311,7 +378,8 @@ void init(dt_view_t *self)
 
   if(darktable.gui)
   {
-    lib->pin = init_pin();
+    lib->image_pin = init_image_pin();
+    lib->place_pin = init_place_pin();
     lib->drop_filmstrip_activated = FALSE;
 
     OsmGpsMapSource_t map_source
@@ -373,13 +441,13 @@ void init(dt_view_t *self)
   lua_State *L = darktable.lua_state.state;
   luaA_Type my_type = dt_lua_module_entry_get_type(L, "view", self->module_name);
   lua_pushcfunction(L, latitude_member);
-  lua_pushcclosure(L,dt_lua_gtk_wrap,1);
+  dt_lua_gtk_wrap(L);
   dt_lua_type_register_type(L, my_type, "latitude");
   lua_pushcfunction(L, longitude_member);
-  lua_pushcclosure(L,dt_lua_gtk_wrap,1);
+  dt_lua_gtk_wrap(L);
   dt_lua_type_register_type(L, my_type, "longitude");
   lua_pushcfunction(L, zoom_member);
-  lua_pushcclosure(L,dt_lua_gtk_wrap,1);
+  dt_lua_gtk_wrap(L);
   dt_lua_type_register_type(L, my_type, "zoom");
 
 #endif // USE_LUA
@@ -400,7 +468,8 @@ void cleanup(dt_view_t *self)
 
   if(darktable.gui)
   {
-    g_object_unref(G_OBJECT(lib->pin));
+    g_object_unref(G_OBJECT(lib->image_pin));
+    g_object_unref(G_OBJECT(lib->place_pin));
     g_object_unref(G_OBJECT(lib->osd));
     osm_gps_map_image_remove_all(lib->map);
     if(lib->images)
@@ -482,9 +551,14 @@ static void _view_map_changed_callback(OsmGpsMap *map, dt_view_t *self)
   DT_DEBUG_SQLITE3_BIND_DOUBLE(lib->statements.main_query, 6, center_lon);
 
   /* remove the old images */
-  osm_gps_map_image_remove_all(map);
   if(lib->images)
   {
+    // we can't use osm_gps_map_image_remove_all() because we want to keep the marker
+    for(GSList *iter = lib->images; iter; iter = g_slist_next(iter))
+    {
+      dt_map_image_t *image = (dt_map_image_t *)iter->data;
+      osm_gps_map_image_remove(map, image->image);
+    }
     g_slist_free_full(lib->images, g_free);
     lib->images = NULL;
   }
@@ -506,7 +580,7 @@ static void _view_map_changed_callback(OsmGpsMap *map, dt_view_t *self)
       for(size_t i = 3; i < (size_t)4 * buf.width * buf.height; i += 4) buf.buf[i] = UINT8_MAX;
 
       int w = _thumb_size, h = _thumb_size;
-      const float _thumb_border = DT_PIXEL_APPLY_DPI(thumb_border), _pin_size = DT_PIXEL_APPLY_DPI(pin_size);
+      const float _thumb_border = DT_PIXEL_APPLY_DPI(thumb_border), _pin_size = DT_PIXEL_APPLY_DPI(image_pin_size);
       if(buf.width < buf.height)
         w = (buf.width * _thumb_size) / buf.height; // portrait
       else
@@ -528,7 +602,7 @@ static void _view_map_changed_callback(OsmGpsMap *map, dt_view_t *self)
                        (1.0 * w) / buf.width, (1.0 * h) / buf.height, GDK_INTERP_HYPER);
 
       // and finally add the pin
-      gdk_pixbuf_copy_area(lib->pin, 0, 0, w + 2 * _thumb_border, _pin_size, thumb, 0, h + 2 * _thumb_border);
+      gdk_pixbuf_copy_area(lib->image_pin, 0, 0, w + 2 * _thumb_border, _pin_size, thumb, 0, h + 2 * _thumb_border);
 
       const dt_image_t *cimg = dt_image_cache_get(darktable.image_cache, imgid, 'r');
       if(!cimg) goto map_changed_failure;
@@ -585,7 +659,7 @@ static int _view_map_get_img_at_pos(dt_view_t *self, double x, double y)
     OsmGpsMapPoint *pt = (OsmGpsMapPoint *)osm_gps_map_image_get_point(image);
     gint img_x = 0, img_y = 0;
     osm_gps_map_convert_geographic_to_screen(lib->map, pt, &img_x, &img_y);
-    img_y -= DT_PIXEL_APPLY_DPI(pin_size);
+    img_y -= DT_PIXEL_APPLY_DPI(image_pin_size);
     if(x >= img_x && x <= img_x + entry->width && y <= img_y && y >= img_y - entry->height)
       return entry->imgid;
   }
@@ -593,7 +667,7 @@ static int _view_map_get_img_at_pos(dt_view_t *self, double x, double y)
   return 0;
 }
 
-static gboolean _view_map_motion_notify_callback(GtkWidget *w, GdkEventMotion *e, dt_view_t *self)
+static gboolean _view_map_motion_notify_callback(GtkWidget *widget, GdkEventMotion *e, dt_view_t *self)
 {
   dt_map_t *lib = (dt_map_t *)self->data;
 
@@ -645,13 +719,8 @@ static gboolean _view_map_motion_notify_callback(GtkWidget *w, GdkEventMotion *e
       gdk_pixbuf_scale(source, thumb, _thumb_border, _thumb_border, w, h, _thumb_border, _thumb_border,
                        (1.0 * w) / buf.width, (1.0 * h) / buf.height, GDK_INTERP_HYPER);
 
-#if GTK_CHECK_VERSION(3, 10, 0)
       GdkDragContext *context = gtk_drag_begin_with_coordinates(GTK_WIDGET(lib->map), targets,
                                                                 GDK_ACTION_COPY, 1, (GdkEvent *)e, -1, -1);
-#else
-      GdkDragContext *context
-          = gtk_drag_begin(GTK_WIDGET(lib->map), targets, GDK_ACTION_COPY, 1, (GdkEvent *)e);
-#endif
 
       gtk_drag_set_icon_pixbuf(context, thumb, 0, h + 2 * _thumb_border);
 
@@ -731,6 +800,8 @@ void enter(dt_view_t *self)
   darktable.view_manager->proxy.map.center_on_bbox = _view_map_center_on_bbox;
   darktable.view_manager->proxy.map.show_osd = _view_map_show_osd;
   darktable.view_manager->proxy.map.set_map_source = _view_map_set_map_source;
+  darktable.view_manager->proxy.map.add_marker = _view_map_add_marker;
+  darktable.view_manager->proxy.map.remove_marker = _view_map_remove_marker;
 
   /* restore last zoom,location in map */
   float lon = dt_conf_get_float("plugins/map/longitude");
@@ -779,7 +850,7 @@ void mouse_moved(dt_view_t *self, double x, double y, double pressure, int which
 void init_key_accels(dt_view_t *self)
 {
   dt_accel_register_view(self, NC_("accel", "undo"), GDK_KEY_z, GDK_CONTROL_MASK);
-  dt_accel_register_view(self, NC_("accel", "redo"), GDK_KEY_r, GDK_CONTROL_MASK);
+  dt_accel_register_view(self, NC_("accel", "redo"), GDK_KEY_y, GDK_CONTROL_MASK);
   // Film strip shortcuts
   dt_accel_register_view(self, NC_("accel", "toggle film strip"), GDK_KEY_f, GDK_CONTROL_MASK);
 }
@@ -787,10 +858,14 @@ void init_key_accels(dt_view_t *self)
 static gboolean _view_map_undo_callback(GtkAccelGroup *accel_group, GObject *acceleratable, guint keyval,
                                         GdkModifierType modifier, gpointer data)
 {
-  if(keyval == GDK_KEY_z)
-    dt_undo_do_undo(darktable.undo, DT_UNDO_GEOTAG);
-  else
-    dt_undo_do_redo(darktable.undo, DT_UNDO_GEOTAG);
+  dt_undo_do_undo(darktable.undo, DT_UNDO_GEOTAG);
+  return TRUE;
+}
+
+static gboolean _view_map_redo_callback(GtkAccelGroup *accel_group, GObject *acceleratable, guint keyval,
+                                        GdkModifierType modifier, gpointer data)
+{
+  dt_undo_do_redo(darktable.undo, DT_UNDO_GEOTAG);
   return TRUE;
 }
 
@@ -805,8 +880,10 @@ static gboolean film_strip_key_accel(GtkAccelGroup *accel_group, GObject *accele
 
 void connect_key_accels(dt_view_t *self)
 {
+  // undo/redo
   GClosure *closure = g_cclosure_new(G_CALLBACK(_view_map_undo_callback), (gpointer)self, NULL);
   dt_accel_connect_view(self, "undo", closure);
+  closure = g_cclosure_new(G_CALLBACK(_view_map_redo_callback), (gpointer)self, NULL);
   dt_accel_connect_view(self, "redo", closure);
   // Film strip shortcuts
   closure = g_cclosure_new(G_CALLBACK(film_strip_key_accel), (gpointer)self, NULL);
@@ -866,6 +943,104 @@ static void _view_map_set_map_source(const dt_view_t *view, OsmGpsMapSource_t ma
   _view_map_set_map_source_g_object(view, map_source);
 }
 
+static OsmGpsMapImage *_view_map_add_pin(const dt_view_t *view, GList *points)
+{
+  dt_map_t *lib = (dt_map_t *)view->data;
+  dt_geo_map_display_point_t *p = (dt_geo_map_display_point_t *)points->data;
+  return osm_gps_map_image_add_with_alignment(lib->map, p->lat, p->lon, lib->place_pin, 0.5, 1);
+}
+
+static gboolean _view_map_remove_pin(const dt_view_t *view, OsmGpsMapImage *pin)
+{
+  dt_map_t *lib = (dt_map_t *)view->data;
+  return osm_gps_map_image_remove(lib->map, pin);
+}
+
+#ifdef HAVE_OSMGPSMAP_110_OR_NEWER
+static OsmGpsMapPolygon *_view_map_add_polygon(const dt_view_t *view, GList *points)
+{
+  dt_map_t *lib = (dt_map_t *)view->data;
+
+  OsmGpsMapPolygon *poly = osm_gps_map_polygon_new();
+  OsmGpsMapTrack* track = osm_gps_map_track_new();
+
+  for(GList *iter = g_list_first(points); iter; iter = g_list_next(iter))
+  {
+    dt_geo_map_display_point_t *p = (dt_geo_map_display_point_t *)iter->data;
+    OsmGpsMapPoint* point = osm_gps_map_point_new_degrees(p->lat, p->lon);
+    osm_gps_map_track_add_point(track, point);
+  }
+
+  g_object_set(poly, "track", track, (gchar *)0);
+  g_object_set(poly, "editable", FALSE, (gchar *)0);
+
+  osm_gps_map_polygon_add(lib->map, poly);
+
+  return poly;
+}
+
+static gboolean _view_map_remove_polygon(const dt_view_t *view, OsmGpsMapPolygon *polygon)
+{
+  dt_map_t *lib = (dt_map_t *)view->data;
+  return osm_gps_map_polygon_remove(lib->map, polygon);
+}
+#endif
+
+static OsmGpsMapTrack *_view_map_add_track(const dt_view_t *view, GList *points)
+{
+  dt_map_t *lib = (dt_map_t *)view->data;
+
+  OsmGpsMapTrack* track = osm_gps_map_track_new();
+
+  for(GList *iter = g_list_first(points); iter; iter = g_list_next(iter))
+  {
+    dt_geo_map_display_point_t *p = (dt_geo_map_display_point_t *)iter->data;
+    OsmGpsMapPoint* point = osm_gps_map_point_new_degrees(p->lat, p->lon);
+    osm_gps_map_track_add_point(track, point);
+  }
+
+  g_object_set(track, "editable", FALSE, (gchar *)0);
+
+  osm_gps_map_track_add(lib->map, track);
+
+  return track;
+}
+
+static gboolean _view_map_remove_track(const dt_view_t *view, OsmGpsMapTrack *track)
+{
+  dt_map_t *lib = (dt_map_t *)view->data;
+  return osm_gps_map_track_remove(lib->map, track);
+}
+
+static GObject *_view_map_add_marker(const dt_view_t *view, dt_geo_map_display_t type, GList *points)
+{
+  switch(type)
+  {
+    case MAP_DISPLAY_POINT: return G_OBJECT(_view_map_add_pin(view, points));
+    case MAP_DISPLAY_TRACK: return G_OBJECT(_view_map_add_track(view, points));
+#ifdef HAVE_OSMGPSMAP_110_OR_NEWER
+    case MAP_DISPLAY_POLYGON: return G_OBJECT(_view_map_add_polygon(view, points));
+#endif
+    default: return NULL;
+  }
+}
+
+static gboolean _view_map_remove_marker(const dt_view_t *view, dt_geo_map_display_t type, GObject *marker)
+{
+  if(type == MAP_DISPLAY_NONE) return FALSE;
+
+  switch(type)
+  {
+    case MAP_DISPLAY_POINT: return _view_map_remove_pin(view, OSM_GPS_MAP_IMAGE(marker));
+    case MAP_DISPLAY_TRACK: return _view_map_remove_track(view, OSM_GPS_MAP_TRACK(marker));
+#ifdef HAVE_OSMGPSMAP_110_OR_NEWER
+    case MAP_DISPLAY_POLYGON: return _view_map_remove_polygon(view, OSM_GPS_MAP_POLYGON(marker));
+#endif
+    default: return FALSE;
+  }
+}
+
+
 static void _view_map_check_preference_changed(gpointer instance, gpointer user_data)
 {
   dt_view_t *view = (dt_view_t *)user_data;
@@ -909,8 +1084,9 @@ static void _view_map_filmstrip_activate_callback(gpointer instance, gpointer us
   }
 }
 
-static void pop_undo(dt_view_t *self, dt_undo_type_t type, dt_undo_data_t *data)
+static void pop_undo(gpointer user_data, dt_undo_type_t type, dt_undo_data_t *data)
 {
+  dt_view_t *self = (dt_view_t *)user_data;
   dt_map_t *lib = (dt_map_t *)self->data;
 
   if(type == DT_UNDO_GEOTAG)
@@ -932,14 +1108,14 @@ static void pop_undo(dt_view_t *self, dt_undo_type_t type, dt_undo_data_t *data)
 
 static void _push_position(dt_view_t *self, int imgid, float longitude, float latitude, float elevation)
 {
-  dt_undo_geotag_t *geotag = g_malloc(sizeof(dt_undo_geotag_t));
+  dt_undo_geotag_t *geotag = malloc(sizeof(dt_undo_geotag_t));
 
   geotag->imgid = imgid;
   geotag->longitude = longitude;
   geotag->latitude = latitude;
   geotag->elevation = elevation;
 
-  dt_undo_record(darktable.undo, self, DT_UNDO_GEOTAG, (dt_undo_data_t *)geotag, &pop_undo);
+  dt_undo_record(darktable.undo, self, DT_UNDO_GEOTAG, (dt_undo_data_t *)geotag, &pop_undo, free);
 }
 
 static void _get_image_location(dt_view_t *self, int imgid, float *longitude, float *latitude, float *elevation)
@@ -999,7 +1175,7 @@ static void drag_and_drop_received(GtkWidget *widget, GdkDragContext *context, g
     else if(*imgid == -1) // everything which is selected
     {
       sqlite3_stmt *stmt;
-      DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "select distinct imgid from selected_images",
+      DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), "SELECT DISTINCT imgid FROM main.selected_images",
                                   -1, &stmt, NULL);
       while(sqlite3_step(stmt) == SQLITE_ROW)
         _view_map_add_image_to_map(self, sqlite3_column_int(stmt, 0), x, y);
@@ -1097,13 +1273,14 @@ static void _view_map_build_main_query(dt_map_t *lib)
   lib->max_images_drawn = dt_conf_get_int("plugins/map/max_images_drawn");
   if(lib->max_images_drawn == 0) lib->max_images_drawn = 100;
   lib->filter_images_drawn = dt_conf_get_bool("plugins/map/filter_images_drawn");
-  geo_query = g_strdup_printf(
-      "select * from (select id, latitude from %s where \
-                               longitude >= ?1 and longitude <= ?2 and latitude <= ?3 and latitude >= ?4 \
-                               and longitude not NULL and latitude not NULL order by abs(latitude - ?5), abs(longitude - ?6) \
-                               limit 0, %d) order by (180 - latitude), id",
-      lib->filter_images_drawn ? "images i inner join memory.collected_images c on i.id = c.imgid" : "images",
-      lib->max_images_drawn);
+  geo_query = g_strdup_printf("SELECT * FROM (SELECT id, latitude FROM %s WHERE longitude >= ?1 AND "
+                              "longitude <= ?2 AND latitude <= ?3 AND latitude >= ?4 AND longitude NOT NULL AND "
+                              "latitude NOT NULL ORDER BY ABS(latitude - ?5), ABS(longitude - ?6) LIMIT 0, %d) "
+                              "ORDER BY (180 - latitude), id",
+                              lib->filter_images_drawn
+                              ? "main.images i INNER JOIN memory.collected_images c ON i.id = c.imgid"
+                              : "main.images",
+                              lib->max_images_drawn);
 
   /* prepare the main query statement */
   DT_DEBUG_SQLITE3_PREPARE_V2(dt_database_get(darktable.db), geo_query, -1, &lib->statements.main_query, NULL);
@@ -1113,4 +1290,4 @@ static void _view_map_build_main_query(dt_map_t *lib)
 
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
 // vim: shiftwidth=2 expandtab tabstop=2 cindent
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
