@@ -5,8 +5,7 @@
  This file is licensed under a BSD license.
 */
 
-#ifndef __GETRUSAGE_H__
-#define __GETRUSAGE_H__
+#pragma once
 
 #include <sys/time.h> /* for struct timeval */
 
@@ -27,6 +26,6 @@ struct rusage
 
 extern int getrusage(int who, struct rusage *rusage);
 
-#endif
-
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
+// vim: shiftwidth=2 expandtab tabstop=2 cindent
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
