@@ -1,5 +1,4 @@
-#ifndef __WIN_H__
-#define __WIN_H__
+#pragma once
 
 #ifdef __MSVCRT_VERSION__
 #undef __MSVCRT_VERSION__
@@ -20,6 +19,6 @@
 #define sleep(n) Sleep(1000 * n)
 #define HAVE_BOOLEAN
 
-#endif
-
-// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-space on;
+// modelines: These editor modelines have been set for all relevant files by tools/update_modelines.sh
+// vim: shiftwidth=2 expandtab tabstop=2 cindent
+// kate: tab-indents: off; indent-width 2; replace-tabs on; indent-mode cstyle; remove-trailing-spaces modified;
